@@ -117,6 +117,13 @@ OC.L10N.register(
     "No favorites" : "Ei suosikkeja",
     "Files and folders you mark as favorite will show up here" : "Suosikeiksi merkitsemäsi tiedostot ja kansiot näkyvät täällä",
     "Text file" : "Tekstitiedosto",
-    "New text file.txt" : "Uusi tekstitiedosto.txt"
+    "New text file.txt" : "Uusi tekstitiedosto.txt",
+    "Changed by %2$s" : "Muuttanut %2$s",
+    "Deleted by %2$s" : "Poistanut %2$s",
+    "Restored by %2$s" : "Palauttanut %2$s",
+    "You changed %1$s" : "Muutit kohdetta %1$s",
+    "You created %1$s" : "Loit kohteen %1$s",
+    "You deleted %1$s" : "Poistit kohteen %1$s",
+    "You restored %1$s" : "Palautit kohteen %1$s"
 },
 "nplurals=2; plural=(n != 1);");
