@@ -103,8 +103,16 @@ class Share20OCS {
 			'displayname_file_owner' => $shareOwner !== null ? $shareOwner->getDisplayName() : $share->getShareOwner(),
 		];
 
-		$node = $share->getNode();
-		$result['path'] = $this->rootFolder->getUserFolder($share->getShareOwner())->getRelativePath($node->getPath());
+		$userFolder = $this->rootFolder->getUserFolder($this->currentUser->getUID());
+		$nodes = $userFolder->getById($share->getNodeId());
+
+		if (empty($nodes)) {
+			throw new NotFoundException();
+		}
+
+		$node = $nodes[0];
+		$result['path'] = $userFolder->getRelativePath($node->getPath());
+
 		if ($node instanceOf \OCP\Files\Folder) {
 			$result['item_type'] = 'folder';
 		} else {
