@@ -1,8 +1,10 @@
 OC.L10N.register(
     "files_texteditor",
     {
+    "This file is too big to be opened. Please download the file instead." : "이 파일을 열기에 너무 큽니다. 파일을 다운로드하십시오.",
     "Cannot read the file." : "파일을 읽을 수 없습니다.",
-    "Invalid file path supplied." : "잘못된 경로를 지정하였습니다.",
+    "Invalid file path supplied." : "잘못된 경로를 지정했습니다.",
+    "An internal server error occurred." : "내부 서버 오류가 발생했습니다.",
     "Cannot save file as it has been modified since opening" : "파일을 연 후 수정했기 때문에 저장할 수 없음",
     "Insufficient permissions" : "권한 부족",
     "File path not supplied" : "파일 경로가 지정되지 않았음",
@@ -12,6 +14,8 @@ OC.L10N.register(
     "failed!" : "실패했습니다!",
     "Saved" : "저장됨",
     "There was a problem saving your changes. Click to resume editing." : "변경 사항을 저장할 수 없습니다. 편집을 계속하려면 누르십시오.",
-    "An error occurred!" : "오류가 발생하였습니다!"
+    "An error occurred!" : "오류가 발생했습니다!",
+    "Text file" : "텍스트 파일",
+    "New text file.txt" : "새 텍스트 파일.txt"
 },
 "nplurals=1; plural=0;");
