@@ -5,15 +5,17 @@ OC.L10N.register(
     "Couldn't restore %s" : "Non foi posíbel restaurar %s",
     "Deleted files" : "Ficheiros eliminados",
     "Restore" : "Restabelecer",
+    "Delete" : "Eliminar",
     "Delete permanently" : "Eliminar permanentemente",
     "Error" : "Erro",
+    "This operation is forbidden" : "Esta operación está prohibida",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Este directorio non está dispoñíbel, comprobe os rexistros ou póñase en contacto co administrador",
     "restored" : "restaurado",
     "No deleted files" : "Non hai ficheiros eliminados",
     "You will be able to recover deleted files from here" : "Poderá recuperar ficheiros borrados de aquí",
     "No entries found in this folder" : "Non se atoparon entradas neste cartafol",
     "Select all" : "Seleccionar todo",
     "Name" : "Nome",
-    "Deleted" : "Eliminado",
-    "Delete" : "Eliminar"
+    "Deleted" : "Eliminado"
 },
 "nplurals=2; plural=(n != 1);");
