@@ -14,6 +14,7 @@ OC.L10N.register(
     "No entries found in this folder" : "Brak wpisów w tym folderze",
     "Select all" : "Wybierz wszystko",
     "Name" : "Nazwa",
-    "Deleted" : "Usunięte"
+    "Deleted" : "Usunięte",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Ten folder jest niedostępny, proszę sprawdzić logi lub skontaktować się z administratorem."
 },
 "nplurals=3; plural=(n==1 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
