@@ -28,6 +28,12 @@ OCA = OCA || {};
 		 */
 		bjQuiButtonClass: 'ui-button',
 
+		/**
+		 * @property {bool} - indicates whether a filter mode toggle operation
+		 * is still in progress
+		 */
+		isToggling: false,
+
 		/** @inheritdoc */
 		init: function(tabIndex, tabID) {
 			this.tabIndex = tabIndex;
@@ -407,6 +413,20 @@ OCA = OCA || {};
 			this.configModel.requestWizard(this.filterName);
 		},
 
+		/**
+		 * sets the filter mode initially and resets the "isToggling" marker.
+		 * This method is called after a save operation against the mode key.
+		 *
+		 * @param mode
+		 */
+		setFilterModeOnce: function(mode) {
+			this.isToggling = false;
+			if(!this.filterModeInitialized) {
+				this.filterModeInitialized = true;
+				this.setFilterMode(mode);
+			}
+		},
+
 		/**
 		 * sets the filter mode according to the provided configuration value
 		 *
@@ -568,8 +588,15 @@ OCA = OCA || {};
 			this.filterModeDisableableElements = filterModeDisableableElements;
 			this.filterModeStateElement = filterModeStateElement;
 			this.filterModeKey = filterModeKey;
-			$switcher.click(this._toggleRawFilterMode);
-		}
+			var view = this;
+			$switcher.click(function() {
+				if(view.isToggling) {
+					return;
+				}
+				view.isToggling = true;
+				view._toggleRawFilterMode();
+			});
+		},
 
 	});
 
