@@ -9,6 +9,7 @@ OC.L10N.register(
     "Port" : "Gátt",
     "Password" : "Lykilorð",
     "Continue" : "Halda áfram",
-    "Advanced" : "Ítarlegt"
+    "Advanced" : "Ítarlegt",
+    "Server" : "Þjónn"
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
