@@ -28,8 +28,10 @@ describe('OC.Share.ShareDialogView', function() {
 	var avatarStub;
 	var placeholderStub;
 	var oldCurrentUser;
+	var saveLinkShareStub;
 
 	var fetchStub;
+	var notificationStub;
 
 	var configModel;
 	var shareModel;
@@ -46,6 +48,7 @@ describe('OC.Share.ShareDialogView', function() {
 		oc_appconfig.core.enforcePasswordForPublicLink = false;
 
 		fetchStub = sinon.stub(OC.Share.ShareItemModel.prototype, 'fetch');
+		saveLinkShareStub = sinon.stub(OC.Share.ShareItemModel.prototype, 'saveLinkShare');
 
 		fileInfoModel = new OCA.Files.FileInfoModel({
 			id: 123,
@@ -116,6 +119,7 @@ describe('OC.Share.ShareDialogView', function() {
 
 		dialog.remove();
 		fetchStub.restore();
+		saveLinkShareStub.restore();
 
 		autocompleteStub.restore();
 		avatarStub.restore();
@@ -128,55 +132,32 @@ describe('OC.Share.ShareDialogView', function() {
 		it('update password on focus out', function() {
 			$('#allowShareWithLink').val('yes');
 
+			dialog.model.set('linkShare', {
+				isLinkShare: true
+			});
 			dialog.render();
 
-			// Toggle linkshare
-			dialog.$el.find('.linkCheckbox').click();
-			fakeServer.requests[0].respond(
-				200,
-				{ 'Content-Type': 'application/json' },
-				JSON.stringify({data: {token: 'xyz'}, status: 'success'})
-			);
-
 			// Enable password, enter password and focusout
 			dialog.$el.find('[name=showPassword]').click();
 			dialog.$el.find('.linkPassText').focus();
 			dialog.$el.find('.linkPassText').val('foo');
 			dialog.$el.find('.linkPassText').focusout();
 
-			expect(fakeServer.requests[1].method).toEqual('POST');
-			var body = OC.parseQueryString(fakeServer.requests[1].requestBody);
-			expect(body['shareWith[password]']).toEqual('foo');
-			expect(body['shareWith[passwordChanged]']).toEqual('true');
-
-			fetchStub.reset();
-
-			// Set password response
-			fakeServer.requests[1].respond(
-				200,
-				{ 'Content-Type': 'application/json' },
-				JSON.stringify({data: {token: 'xyz'}, status: 'success'})
-			);
-
-			expect(fetchStub.calledOnce).toEqual(true);
-			// fetching the model will rerender the view
-			dialog.render();
-
-			expect(dialog.$el.find('.linkPassText').val()).toEqual('');
-			expect(dialog.$el.find('.linkPassText').attr('placeholder')).toEqual('**********');
+			expect(saveLinkShareStub.calledOnce).toEqual(true);
+			expect(saveLinkShareStub.firstCall.args[0]).toEqual({
+				password: 'foo'
+			});
 		});
 		it('update password on enter', function() {
 			$('#allowShareWithLink').val('yes');
 
+			dialog.model.set('linkShare', {
+				isLinkShare: true
+			});
 			dialog.render();
 
 			// Toggle linkshare
 			dialog.$el.find('.linkCheckbox').click();
-			fakeServer.requests[0].respond(
-				200,
-				{ 'Content-Type': 'application/json' },
-				JSON.stringify({data: {token: 'xyz'}, status: 'success'})
-			);
 
 			// Enable password and enter password
 			dialog.$el.find('[name=showPassword]').click();
@@ -184,26 +165,10 @@ describe('OC.Share.ShareDialogView', function() {
 			dialog.$el.find('.linkPassText').val('foo');
 			dialog.$el.find('.linkPassText').trigger(new $.Event('keyup', {keyCode: 13}));
 
-			expect(fakeServer.requests[1].method).toEqual('POST');
-			var body = OC.parseQueryString(fakeServer.requests[1].requestBody);
-			expect(body['shareWith[password]']).toEqual('foo');
-			expect(body['shareWith[passwordChanged]']).toEqual('true');
-
-			fetchStub.reset();
-
-			// Set password response
-			fakeServer.requests[1].respond(
-				200,
-				{ 'Content-Type': 'application/json' },
-				JSON.stringify({data: {token: 'xyz'}, status: 'success'})
-			);
-
-			expect(fetchStub.calledOnce).toEqual(true);
-			// fetching the model will rerender the view
-			dialog.render();
-
-			expect(dialog.$el.find('.linkPassText').val()).toEqual('');
-			expect(dialog.$el.find('.linkPassText').attr('placeholder')).toEqual('**********');
+			expect(saveLinkShareStub.calledOnce).toEqual(true);
+			expect(saveLinkShareStub.firstCall.args[0]).toEqual({
+				password: 'foo'
+			});
 		});
 		it('shows share with link checkbox when allowed', function() {
 			$('#allowShareWithLink').val('yes');
@@ -241,16 +206,11 @@ describe('OC.Share.ShareDialogView', function() {
 		it('autofocus link text when clicked', function() {
 			$('#allowShareWithLink').val('yes');
 
+			dialog.model.set('linkShare', {
+				isLinkShare: true
+			});
 			dialog.render();
 
-			// Toggle linkshare
-			dialog.$el.find('.linkCheckbox').click();
-			fakeServer.requests[0].respond(
-				200,
-				{ 'Content-Type': 'application/json' },
-				JSON.stringify({data: {token: 'xyz'}, status: 'success'})
-			);
-
 			var focusStub = sinon.stub($.fn, 'focus');
 			var selectStub = sinon.stub($.fn, 'select');
 			dialog.$el.find('.linkText').click();
@@ -466,15 +426,15 @@ describe('OC.Share.ShareDialogView', function() {
 				clock.restore();
 			});
 
-			it('displayes form when sending emails is enabled', function() {
+			it('displays form when sending emails is enabled', function() {
 				$('input[name=mailPublicNotificationEnabled]').val('yes');
 				dialog.render();
-				expect(dialog.$('#emailPrivateLink').length).toEqual(1);
+				expect(dialog.$('.emailPrivateLinkForm').length).toEqual(1);
 			});
 			it('form not rendered when sending emails is disabled', function() {
 				$('input[name=mailPublicNotificationEnabled]').val('no');
 				dialog.render();
-				expect(dialog.$('#emailPrivateLink').length).toEqual(0);
+				expect(dialog.$('.emailPrivateLinkForm').length).toEqual(0);
 			});
 			it('input cleared on success', function() {
 				var defer = $.Deferred();
@@ -483,17 +443,17 @@ describe('OC.Share.ShareDialogView', function() {
 				$('input[name=mailPublicNotificationEnabled]').val('yes');
 				dialog.render();
 
-				dialog.$el.find('#emailPrivateLink #email').val('a@b.c');
-				dialog.$el.find('#emailPrivateLink').trigger('submit');
+				dialog.$el.find('.emailPrivateLinkForm .emailField').val('a@b.c');
+				dialog.$el.find('.emailPrivateLinkForm').trigger('submit');
 
 				expect(sendEmailPrivateLinkStub.callCount).toEqual(1);
-				expect(dialog.$el.find('#emailPrivateLink #email').val()).toEqual('Sending ...');
+				expect(dialog.$el.find('.emailPrivateLinkForm .emailField').val()).toEqual('Sending ...');
 
 				defer.resolve();
-				expect(dialog.$el.find('#emailPrivateLink #email').val()).toEqual('Email sent');
+				expect(dialog.$el.find('.emailPrivateLinkForm .emailField').val()).toEqual('Email sent');
 
 				clock.tick(2000);
-				expect(dialog.$el.find('#emailPrivateLink #email').val()).toEqual('');
+				expect(dialog.$el.find('.emailPrivateLinkForm .emailField').val()).toEqual('');
 			});
 			it('input not cleared on failure', function() {
 				var defer = $.Deferred();
@@ -502,14 +462,14 @@ describe('OC.Share.ShareDialogView', function() {
 				$('input[name=mailPublicNotificationEnabled]').val('yes');
 				dialog.render();
 
-				dialog.$el.find('#emailPrivateLink #email').val('a@b.c');
-				dialog.$el.find('#emailPrivateLink').trigger('submit');
+				dialog.$el.find('.emailPrivateLinkForm .emailField').val('a@b.c');
+				dialog.$el.find('.emailPrivateLinkForm').trigger('submit');
 
 				expect(sendEmailPrivateLinkStub.callCount).toEqual(1);
-				expect(dialog.$el.find('#emailPrivateLink #email').val()).toEqual('Sending ...');
+				expect(dialog.$el.find('.emailPrivateLinkForm .emailField').val()).toEqual('Sending ...');
 
 				defer.reject();
-				expect(dialog.$el.find('#emailPrivateLink #email').val()).toEqual('a@b.c');
+				expect(dialog.$el.find('.emailPrivateLinkForm .emailField').val()).toEqual('a@b.c');
 			});
 		});
 	});
@@ -603,26 +563,405 @@ describe('OC.Share.ShareDialogView', function() {
 			});
 		});
 	});
-	describe('share permissions', function() {
-		beforeEach(function() {
-			oc_appconfig.core.resharingAllowed = true;
-		});
-
-		/**
-		 * Tests sharing with the given possible permissions
-		 *
-		 * @param {int} possiblePermissions
-		 * @return {int} permissions sent to the server
-		 */
-		function testWithPermissions(possiblePermissions) {
-			shareModel.set({
-				permissions: possiblePermissions,
-				possiblePermissions: possiblePermissions
+	describe('remote sharing', function() {
+		it('shows remote share info when allowed', function() {
+			configModel.set({
+				isRemoteShareAllowed: true
 			});
 			dialog.render();
+			expect(dialog.$el.find('.shareWithRemoteInfo').length).toEqual(1);
+		});
+		it('does not show remote share info when not allowed', function() {
+			configModel.set({
+				isRemoteShareAllowed: false
+			});
+			dialog.render();
+			expect(dialog.$el.find('.shareWithRemoteInfo').length).toEqual(0);
+		});
+	});
+	describe('autocompletion of users', function() {
+		it('triggers autocomplete display and focus with data when ajax search succeeds', function () {
+			dialog.render();
+			var response = sinon.stub();
+			dialog.autocompleteHandler({term: 'bob'}, response);
+			var jsonData = JSON.stringify({
+				'ocs' : {
+					'meta' : {
+						'status' : 'success',
+						'statuscode' : 100,
+						'message' : null
+					},
+					'data' : {
+						'exact' : {
+							'users'  : [],
+							'groups' : [],
+							'remotes': []
+						},
+						'users'  : [{'label': 'bob', 'value': {'shareType': 0, 'shareWith': 'test'}}],
+						'groups' : [],
+						'remotes': []
+					}
+				}
+			});
+			fakeServer.requests[0].respond(
+					200,
+					{'Content-Type': 'application/json'},
+					jsonData
+			);
+			expect(response.calledWithExactly(JSON.parse(jsonData).ocs.data.users)).toEqual(true);
+			expect(autocompleteStub.calledWith("option", "autoFocus", true)).toEqual(true);
+		});
+
+		describe('filter out', function() {
+			it('the current user', function () {
+				dialog.render();
+				var response = sinon.stub();
+				dialog.autocompleteHandler({term: 'bob'}, response);
+				var jsonData = JSON.stringify({
+					'ocs': {
+						'meta': {
+							'status': 'success',
+							'statuscode': 100,
+							'message': null
+						},
+						'data': {
+							'exact': {
+								'users': [],
+								'groups': [],
+								'remotes': []
+							},
+							'users': [
+								{
+									'label': 'bob',
+									'value': {
+										'shareType': 0,
+										'shareWith': OC.currentUser
+									}
+								},
+								{
+									'label': 'bobby',
+									'value': {
+										'shareType': 0,
+										'shareWith': 'imbob'
+									}
+								}
+							],
+							'groups': [],
+							'remotes': []
+						}
+					}
+				});
+				fakeServer.requests[0].respond(
+					200,
+					{'Content-Type': 'application/json'},
+					jsonData
+				);
+				expect(response.calledWithExactly([{
+					'label': 'bobby',
+					'value': {'shareType': 0, 'shareWith': 'imbob'}
+				}])).toEqual(true);
+				expect(autocompleteStub.calledWith("option", "autoFocus", true)).toEqual(true);
+			});
+
+			it('the share owner', function () {
+				shareModel.set({
+					reshare: {
+						uid_owner: 'user1'
+					},
+					shares: [],
+					permissions: OC.PERMISSION_READ
+				});
+
+				dialog.render();
+				var response = sinon.stub();
+				dialog.autocompleteHandler({term: 'bob'}, response);
+				var jsonData = JSON.stringify({
+					'ocs': {
+						'meta': {
+							'status': 'success',
+							'statuscode': 100,
+							'message': null
+						},
+						'data': {
+							'exact': {
+								'users': [],
+								'groups': [],
+								'remotes': []
+							},
+							'users': [
+								{
+									'label': 'bob',
+									'value': {
+										'shareType': 0,
+										'shareWith': 'user1'
+									}
+								},
+								{
+									'label': 'bobby',
+									'value': {
+										'shareType': 0,
+										'shareWith': 'imbob'
+									}
+								}
+							],
+							'groups': [],
+							'remotes': []
+						}
+					}
+				});
+				fakeServer.requests[0].respond(
+					200,
+					{'Content-Type': 'application/json'},
+					jsonData
+				);
+				expect(response.calledWithExactly([{
+					'label': 'bobby',
+					'value': {'shareType': 0, 'shareWith': 'imbob'}
+				}])).toEqual(true);
+				expect(autocompleteStub.calledWith("option", "autoFocus", true)).toEqual(true);
+			});
+
+			describe('already shared with', function () {
+				beforeEach(function() {
+					shareModel.set({
+						reshare: {},
+						shares: [{
+							id: 100,
+							item_source: 123,
+							permissions: 31,
+							share_type: OC.Share.SHARE_TYPE_USER,
+							share_with: 'user1',
+							share_with_displayname: 'User One'
+						},{
+							id: 101,
+							item_source: 123,
+							permissions: 31,
+							share_type: OC.Share.SHARE_TYPE_GROUP,
+							share_with: 'group',
+							share_with_displayname: 'group'
+						},{
+							id: 102,
+							item_source: 123,
+							permissions: 31,
+							share_type: OC.Share.SHARE_TYPE_REMOTE,
+							share_with: 'foo@bar.com/baz',
+							share_with_displayname: 'foo@bar.com/baz'
+
+						}]
+					});
+				});
+
+				it('users', function () {
+					dialog.render();
+					var response = sinon.stub();
+					dialog.autocompleteHandler({term: 'bob'}, response);
+					var jsonData = JSON.stringify({
+						'ocs': {
+							'meta': {
+								'status': 'success',
+								'statuscode': 100,
+								'message': null
+							},
+							'data': {
+								'exact': {
+									'users': [],
+									'groups': [],
+									'remotes': []
+								},
+								'users': [
+									{
+										'label': 'bob',
+										'value': {
+											'shareType': OC.Share.SHARE_TYPE_USER,
+											'shareWith': 'user1'
+										}
+									},
+									{
+										'label': 'bobby',
+										'value': {
+											'shareType': OC.Share.SHARE_TYPE_USER,
+											'shareWith': 'imbob'
+										}
+									}
+								],
+								'groups': [],
+								'remotes': []
+							}
+						}
+					});
+					fakeServer.requests[0].respond(
+						200,
+						{'Content-Type': 'application/json'},
+						jsonData
+					);
+					expect(response.calledWithExactly([{
+						'label': 'bobby',
+						'value': {'shareType': OC.Share.SHARE_TYPE_USER, 'shareWith': 'imbob'}
+					}])).toEqual(true);
+					expect(autocompleteStub.calledWith("option", "autoFocus", true)).toEqual(true);
+				});
+
+				it('groups', function () {
+					dialog.render();
+					var response = sinon.stub();
+					dialog.autocompleteHandler({term: 'group'}, response);
+					var jsonData = JSON.stringify({
+						'ocs': {
+							'meta': {
+								'status': 'success',
+								'statuscode': 100,
+								'message': null
+							},
+							'data': {
+								'exact': {
+									'users': [],
+									'groups': [],
+									'remotes': []
+								},
+								'users': [],
+								'groups': [
+									{
+										'label': 'group',
+										'value': {
+											'shareType': OC.Share.SHARE_TYPE_GROUP,
+											'shareWith': 'group'
+										}
+									},
+									{
+										'label': 'group2',
+										'value': {
+											'shareType': OC.Share.SHARE_TYPE_GROUP,
+											'shareWith': 'group2'
+										}
+									}
+								],
+								'remotes': []
+							}
+						}
+					});
+					fakeServer.requests[0].respond(
+						200,
+						{'Content-Type': 'application/json'},
+						jsonData
+					);
+					expect(response.calledWithExactly([{
+						'label': 'group2',
+						'value': {'shareType': OC.Share.SHARE_TYPE_GROUP, 'shareWith': 'group2'}
+					}])).toEqual(true);
+					expect(autocompleteStub.calledWith("option", "autoFocus", true)).toEqual(true);
+				});
+
+				it('remotes', function () {
+					dialog.render();
+					var response = sinon.stub();
+					dialog.autocompleteHandler({term: 'bob'}, response);
+					var jsonData = JSON.stringify({
+						'ocs': {
+							'meta': {
+								'status': 'success',
+								'statuscode': 100,
+								'message': null
+							},
+							'data': {
+								'exact': {
+									'users': [],
+									'groups': [],
+									'remotes': []
+								},
+								'users': [],
+								'groups': [],
+								'remotes': [
+									{
+										'label': 'foo@bar.com/baz',
+										'value': {
+											'shareType': OC.Share.SHARE_TYPE_REMOTE,
+											'shareWith': 'foo@bar.com/baz'
+										}
+									},
+									{
+										'label': 'foo2@bar.com/baz',
+										'value': {
+											'shareType': OC.Share.SHARE_TYPE_REMOTE,
+											'shareWith': 'foo2@bar.com/baz'
+										}
+									}
+								]
+							}
+						}
+					});
+					fakeServer.requests[0].respond(
+						200,
+						{'Content-Type': 'application/json'},
+						jsonData
+					);
+					expect(response.calledWithExactly([{
+						'label': 'foo2@bar.com/baz',
+						'value': {'shareType': OC.Share.SHARE_TYPE_REMOTE, 'shareWith': 'foo2@bar.com/baz'}
+					}])).toEqual(true);
+					expect(autocompleteStub.calledWith("option", "autoFocus", true)).toEqual(true);
+				});
+			});
+		});
+
+		it('gracefully handles successful ajax call with failure content', function () {
+			dialog.render();
+			var response = sinon.stub();
+			dialog.autocompleteHandler({term: 'bob'}, response);
+			var jsonData = JSON.stringify({
+				'ocs' : {
+					'meta' : {
+						'status': 'failure',
+						'statuscode': 400
+					}
+				}
+			});
+			fakeServer.requests[0].respond(
+					200,
+					{'Content-Type': 'application/json'},
+					jsonData
+			);
+			expect(response.calledWithExactly()).toEqual(true);
+		});
+
+		it('throws a notification when the ajax search lookup fails', function () {
+			notificationStub = sinon.stub(OC.Notification, 'show');
+			dialog.render();
+			dialog.autocompleteHandler({term: 'bob'}, sinon.stub());
+			fakeServer.requests[0].respond(500);
+			expect(notificationStub.calledOnce).toEqual(true);
+			notificationStub.restore();
+		});
+
+		describe('renders the autocomplete elements', function() {
+			it('renders a group element', function() {
+				dialog.render();
+				var el = dialog.autocompleteRenderItem(
+						$("<ul></ul>"),
+						{label: "1", value: { shareType: OC.Share.SHARE_TYPE_GROUP }}
+				);
+				expect(el.is('li')).toEqual(true);
+				expect(el.hasClass('group')).toEqual(true);
+			});
+
+			it('renders a remote element', function() {
+				dialog.render();
+				var el = dialog.autocompleteRenderItem(
+						$("<ul></ul>"),
+						{label: "1", value: { shareType: OC.Share.SHARE_TYPE_REMOTE }}
+				);
+				expect(el.is('li')).toEqual(true);
+				expect(el.hasClass('user')).toEqual(true);
+			});
+		});
+
+		it('calls addShare after selection', function() {
+			dialog.render();
+
+			var shareWith = $('.shareWithField')[0];
+			var $shareWith = $(shareWith);
+			var addShareStub = sinon.stub(shareModel, 'addShare');
 			var autocompleteOptions = autocompleteStub.getCall(0).args[0];
-			// simulate autocomplete selection
-			autocompleteOptions.select(new $.Event('select'), {
+			autocompleteOptions.select(new $.Event('select', {target: shareWith}), {
 				item: {
 					label: 'User Two',
 					value: {
@@ -631,76 +970,95 @@ describe('OC.Share.ShareDialogView', function() {
 					}
 				}
 			});
-			autocompleteStub.reset();
-			var requestBody = OC.parseQueryString(_.last(fakeServer.requests).requestBody);
-			return parseInt(requestBody.permissions, 10);
-		}
 
-		describe('regular sharing', function() {
-			it('shares with given permissions with default config', function() {
-				shareModel.set({
-					reshare: {},
-					shares: []
-				});
-				expect(
-					testWithPermissions(OC.PERMISSION_READ | OC.PERMISSION_UPDATE | OC.PERMISSION_SHARE)
-				).toEqual(OC.PERMISSION_READ | OC.PERMISSION_UPDATE | OC.PERMISSION_SHARE);
-				expect(
-					testWithPermissions(OC.PERMISSION_READ | OC.PERMISSION_SHARE)
-				).toEqual(OC.PERMISSION_READ | OC.PERMISSION_SHARE);
+			expect(addShareStub.calledOnce).toEqual(true);
+			expect(addShareStub.firstCall.args[0]).toEqual({
+				shareType: OC.Share.SHARE_TYPE_USER,
+				shareWith: 'user2'
 			});
-			it('removes share permission when not allowed', function() {
-				configModel.set('isResharingAllowed', false);
-				shareModel.set({
-					reshare: {},
-					shares: []
-				});
-				expect(
-					testWithPermissions(OC.PERMISSION_READ | OC.PERMISSION_UPDATE | OC.PERMISSION_SHARE)
-				).toEqual(OC.PERMISSION_READ | OC.PERMISSION_UPDATE);
+
+			//Input is locked
+			expect($shareWith.val()).toEqual('User Two');
+			expect($shareWith.attr('disabled')).toEqual('disabled');
+
+			//Callback is called
+			addShareStub.firstCall.args[1].success();
+
+			//Input is unlocked
+			expect($shareWith.val()).toEqual('');
+			expect($shareWith.attr('disabled')).toEqual(undefined);
+
+			addShareStub.restore();
+		});
+
+		it('calls addShare after selection and fail to share', function() {
+			dialog.render();
+
+			var shareWith = $('.shareWithField')[0];
+			var $shareWith = $(shareWith);
+			var addShareStub = sinon.stub(shareModel, 'addShare');
+			var autocompleteOptions = autocompleteStub.getCall(0).args[0];
+			autocompleteOptions.select(new $.Event('select', {target: shareWith}), {
+				item: {
+					label: 'User Two',
+					value: {
+						shareType: OC.Share.SHARE_TYPE_USER,
+						shareWith: 'user2'
+					}
+				}
 			});
-			it('automatically adds READ permission even when not specified', function() {
-				configModel.set('isResharingAllowed', false);
-				shareModel.set({
-					reshare: {},
-					shares: []
-				});
-				expect(
-					testWithPermissions(OC.PERMISSION_UPDATE | OC.PERMISSION_SHARE)
-				).toEqual(OC.PERMISSION_READ | OC.PERMISSION_UPDATE | OC.PERMISSION_UPDATE);
+
+			expect(addShareStub.calledOnce).toEqual(true);
+			expect(addShareStub.firstCall.args[0]).toEqual({
+				shareType: OC.Share.SHARE_TYPE_USER,
+				shareWith: 'user2'
 			});
-			it('does not show sharing options when sharing not allowed', function() {
-				shareModel.set({
-					reshare: {},
-					shares: [],
-					permissions: OC.PERMISSION_READ
-				});
-				dialog.render();
-				expect(dialog.$el.find('.shareWithField').prop('disabled')).toEqual(true);
+
+			//Input is locked
+			expect($shareWith.val()).toEqual('User Two');
+			expect($shareWith.attr('disabled')).toEqual('disabled');
+
+			//Callback is called
+			addShareStub.firstCall.args[1].error();
+
+			//Input is unlocked
+			expect($shareWith.val()).toEqual('User Two');
+			expect($shareWith.attr('disabled')).toEqual(undefined);
+
+			addShareStub.restore();
+		});
+	});
+	describe('reshare permissions', function() {
+		it('does not show sharing options when sharing not allowed', function() {
+			shareModel.set({
+				reshare: {},
+				shares: [],
+				permissions: OC.PERMISSION_READ
 			});
-			it('shows reshare owner', function() {
-				shareModel.set({
-					reshare: {
-						uid_owner: 'user1'
-					},
-					shares: [],
-					permissions: OC.PERMISSION_READ
-				});
-				dialog.render();
-				expect(dialog.$el.find('.resharerInfoView .reshare').length).toEqual(1);
+			dialog.render();
+			expect(dialog.$el.find('.shareWithField').prop('disabled')).toEqual(true);
+		});
+		it('shows reshare owner', function() {
+			shareModel.set({
+				reshare: {
+					uid_owner: 'user1'
+				},
+				shares: [],
+				permissions: OC.PERMISSION_READ
 			});
-			it('does not show reshare owner if owner is current user', function() {
-				shareModel.set({
-					reshare: {
-						uid_owner: OC.currentUser
-					},
-					shares: [],
-					permissions: OC.PERMISSION_READ
-				});
-				dialog.render();
-				expect(dialog.$el.find('.resharerInfoView .reshare').length).toEqual(0);
+			dialog.render();
+			expect(dialog.$el.find('.resharerInfoView .reshare').length).toEqual(1);
+		});
+		it('does not show reshare owner if owner is current user', function() {
+			shareModel.set({
+				reshare: {
+					uid_owner: OC.currentUser
+				},
+				shares: [],
+				permissions: OC.PERMISSION_READ
 			});
+			dialog.render();
+			expect(dialog.$el.find('.resharerInfoView .reshare').length).toEqual(0);
 		});
 	});
 });
-
