@@ -3,19 +3,21 @@ OC.L10N.register(
     {
     "Couldn't send mail to following users: %s " : "Tidak dapat mengirim Email ke pengguna berikut: %s",
     "Preparing update" : "Mempersiapkan pembaruan",
-    "Migration tests are skipped - \"update.skip-migration-test\" is activated in config.php" : "Percobaan migrasi dilompati - \"update.skip-migration-test\" diaktikan di config.php",
     "Turned on maintenance mode" : "Hidupkan mode perawatan",
     "Turned off maintenance mode" : "Matikan mode perawatan",
     "Maintenance mode is kept active" : "Mode Pemeliharaan masih aktif",
+    "Updating database schema" : "Memperbarui skema basis data",
     "Updated database" : "Basis data terbaru",
+    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Memeriksa apakah skema basis data dapat diperbarui (dapat memerlukan waktu yang lama tergantung pada ukuran basis data)",
     "Checked database schema update" : "Pembaruan skema basis data terperiksa",
+    "Checking updates of apps" : "Memeriksa pembaruan aplikasi",
+    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Memeriksa apakah skema untuk %s dapat diperbarui (dapat memerlukan waktu yang lama tergantung pada ukuran basis data)",
     "Checked database schema update for apps" : "Pembaruan skema basis data terperiksa untuk aplikasi",
     "Updated \"%s\" to %s" : "Terbaru \"%s\" sampai %s",
     "Repair warning: " : "Peringatan perbaikan:",
     "Repair error: " : "Kesalahan perbaikan:",
-    "Set log level to debug - current level: \"%s\"" : "Atur level log untuk debug - level saat ini: \"%s\"",
-    "Reset log level to  \"%s\"" : "Atur ulang level log menjadi \"%s\"",
-    "Following incompatible apps have been disabled: %s" : "Aplikasi tidak kompatibel berikut telah dinonaktifkan: %s",
+    "%s (3rdparty)" : "%s (pihak ke-3)",
+    "%s (incompatible)" : "%s (tidak kompatibel)",
     "Following apps have been disabled: %s" : "Aplikasi berikut telah dinonaktifkan: %s",
     "Already up to date" : "Sudah yang terbaru",
     "File is too big" : "Berkas terlalu besar",
@@ -23,10 +25,16 @@ OC.L10N.register(
     "No image or file provided" : "Tidak ada gambar atau berkas yang disediakan",
     "Unknown filetype" : "Tipe berkas tidak dikenal",
     "Invalid image" : "Gambar tidak sah",
+    "An error occurred. Please contact your admin." : "Terjadi kesalahan. Silakan hubungi admin Anda.",
     "No temporary profile picture available, try again" : "Tidak ada gambar profil sementara yang tersedia, coba lagi",
     "No crop data provided" : "Tidak ada data krop tersedia",
     "No valid crop data provided" : "Tidak ada data valid untuk dipangkas",
     "Crop is not square" : "Pangkas ini tidak persegi",
+    "Couldn't reset password because the token is invalid" : "Tidak dapat menyetel ulang sandi karena token tidak sah",
+    "Couldn't reset password because the token is expired" : "Tidak dapat menyetel ulang sandi karena token telah kadaluarsa",
+    "Couldn't send reset email. Please make sure your username is correct." : "Tidak dapat menyetel ulang email. Mohon pastikan nama pengguna Anda benar.",
+    "%s password reset" : "%s sandi disetel ulang",
+    "Couldn't send reset email. Please contact your administrator." : "Tidak dapat mengirim email setel ulang. Silakan hubungi administrator Anda.",
     "Sunday" : "Minggu",
     "Monday" : "Senin",
     "Tuesday" : "Selasa",
@@ -74,8 +82,8 @@ OC.L10N.register(
     "Dec." : "Des.",
     "Settings" : "Pengaturan",
     "Saving..." : "Menyimpan...",
+    "Dismiss" : "Buang",
     "seconds ago" : "beberapa detik yang lalu",
-    "Couldn't send reset email. Please contact your administrator." : "Tidak dapat mengirim email setel ulang. Silakan hubungi administrator Anda.",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Sebuah tautan untuk setel ulang sandi Anda telah dikirim ke email Anda. Jika Anda tidak menerima dalam jangka waktu yang wajar, periksa folder spam/sampah Anda.<br>Jika tidak ada, tanyakan pada administrator Anda.",
     "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Berkas-berkas Anda terenkripsi. Jika Anda tidak mengaktifkan kunci pemulihan, tidak ada cara lain untuk mendapatkan data Anda kembali setelah sandi di setel ulang.<br />Jika Anda tidak yakin dengan apa yang akan Anda dilakukan, mohon hubungi administrator Anda sebelum melanjutkan. <br />Apakah Anda yakin ingin melanjutkan?",
     "I know what I'm doing" : "Saya tahu apa yang saya lakukan",
@@ -105,27 +113,21 @@ OC.L10N.register(
     "Strong password" : "Sandi kuat",
     "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Server web Anda belum diatur dengan benar untuk mengizinkan sinkronisasi berkas karena antarmuka WebDAV nampaknya rusak.",
     "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Server ini tidak tersambung ke internet. Ini berarti beberapa fitur seperti me-mount penyimpanan eksternal, notifikasi pembaruan atau instalasi aplikasi pihak ketiga tidak akan bekerja. Mengakses berkas secara remote dan mengirim notifikasi email juga tidak bekerja. Kami menyarankan untuk mengaktifkan koneksi internet untuk server ini jika Anda ingin memiliki fitur ini.",
-    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Direktori data dan berkas Anda kemungkinan dapat diakses dari Internet. Berkas .htaccess tidak bekerja. Kami sangat menyarankan Anda untuk mengkonfigurasi server web agar direktori data tidak lagi dapat diakses atau pindahkan direktori data Anda di luar root dokumen server web.",
-    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "Tembolok memori tidak dikonfigurasi. Untuk meningkatkan kinerja, mohon konfigurasi memcache jika tersedia. Informasi lebih lanjut dapat ditemukan di <a href=\"{docLink}\">dokumentasi</a> kami.",
-    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "/dev/urandom tidak terbaca oleh PHP sangat disarankan untuk alasan keamanan. Informasi lebih lanjut dapat ditemukan di <a href=\"{docLink}\">dokumentasi</a> kami.",
-    "Your PHP version ({version}) is no longer <a href=\"{phpLink}\">supported by PHP</a>. We encourage you to upgrade your PHP version to take advantage of performance and security updates provided by PHP." : "Versi PHP Anda ({version}) tidak lagi <a href=\"{phpLink}\">didukung oleh PHP</a>. Kami menyarankan Anda untuk meningkatkan versi PHP Anda agar mendapatkan keuntungan pembaruan kinerja dan keamanan yang disediakan oleh PHP.",
-    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "Konfigurasi header reverse proxy tidak benar atau Anda mengakses ownCloud dari proxy yang tidak terpercaya. Jika Anda tidak mengakses ownCloud dari proxy yang terpercaya, ini merupakan masalah keamanan dan memungkinkan peretas dapat memalsukan alamat IP mereka yang terlihat pada ownCloud. Informasi lebih lanjut dapat ditemukan pada <a href=\"{docLink}\">dokumentasi</a> kami.",
-    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached diatur sebagai cache terdistribusi, namun modul PHP \"memcache\" yang dipasang salah. \\OC\\Memcache\\Memcached hanya mendukung \"memcached\" bukan \"memcache\". Lihat <a href=\"{wikiLink}\">wiki memcached tentang kedua modul</a>.",
     "Error occurred while checking server setup" : "Kesalahan tidak terduga saat memeriksa setelan server",
+    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Direktori data dan berkas Anda kemungkinan dapat diakses dari Internet. Berkas .htaccess tidak bekerja. Kami sangat menyarankan Anda untuk mengkonfigurasi server web agar direktori data tidak lagi dapat diakses atau pindahkan direktori data Anda di luar root dokumen server web.",
     "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "Header HTTP \"{header}\" tidak dikonfigurasi sama dengan \"{expected}\". Hal ini berpotensi pada resiko keamanan dan privasi. Kami sarankan untuk menyesuaikan pengaturan ini.",
-    "The \"Strict-Transport-Security\" HTTP header is not configured to least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\">security tips</a>." : "HTTP header \"Strict-Transport-Security\" tidak diatur kurang dari \"{seconds}\" detik. Untuk peningkatan keamanan, kami menyarankan untuk mengaktifkan HSTS seperti yang dijelaskan di <a href=\"{docUrl}\">tips keamanan</a>.",
     "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "Anda mengakses situs ini via HTTP. Kami sangat menyarankan Anda untuk mengatur server Anda menggunakan HTTPS yang dibahas di <a href=\"{docUrl}\">tips keamanan</a> kami.",
     "Shared" : "Dibagikan",
     "Shared with {recipients}" : "Dibagikan dengan {recipients}",
     "Error" : "Kesalahan",
     "Error while sharing" : "Kesalahan saat membagikan",
     "Error while unsharing" : "Kesalahan saat membatalkan pembagian",
-    "Error while changing permissions" : "Kesalahan saat mengubah izin",
     "Error setting expiration date" : "Kesalahan saat mengatur tanggal kedaluwarsa",
     "The public link will expire no later than {days} days after it is created" : "Tautan publik akan kadaluarsa tidak lebih dari {days} hari setelah ini dibuat",
     "Set expiration date" : "Atur tanggal kedaluwarsa",
     "Expiration" : "Kedaluwarsa",
     "Expiration date" : "Tanggal kedaluwarsa",
+    "Choose a password for the public link" : "Tetapkan sandi untuk tautan publik",
     "Sending ..." : "Mengirim ...",
     "Email sent" : "Email terkirim",
     "Resharing is not allowed" : "Berbagi ulang tidak diizinkan",
@@ -133,13 +135,11 @@ OC.L10N.register(
     "Link" : "Tautan",
     "Password protect" : "Lindungi dengan sandi",
     "Password" : "Sandi",
-    "Choose a password for the public link" : "Tetapkan sandi untuk tautan publik",
     "Allow editing" : "Izinkan penyuntingan",
     "Email link to person" : "Emailkan tautan ini ke orang",
     "Send" : "Kirim",
     "Shared with you and the group {group} by {owner}" : "Dibagikan dengan anda dan grup {group} oleh {owner}",
     "Shared with you by {owner}" : "Dibagikan dengan anda oleh {owner}",
-    "Shared in {item} with {user}" : "Dibagikan dalam {item} dengan {user}",
     "group" : "grup",
     "remote" : "remote",
     "notify by email" : "notifikasi via email",
@@ -158,9 +158,10 @@ OC.L10N.register(
     "Share with users, groups or remote users …" : "Bagikan dengan pengguna, grup atau pengguna remote ...",
     "Warning" : "Peringatan",
     "Error while sending notification" : "Kesalahan ketika mengirim notifikasi",
+    "Delete" : "Hapus",
+    "Rename" : "Ubah nama",
     "The object type is not specified." : "Tipe objek tidak ditentukan.",
     "Enter new" : "Masukkan baru",
-    "Delete" : "Hapus",
     "Add" : "Tambah",
     "Edit tags" : "Sunting label",
     "Error loading dialog template: {error}" : "Kesalahan saat memuat templat dialog: {error}",
@@ -171,21 +172,13 @@ OC.L10N.register(
     "Hello {name}, the weather is {weather}" : "Helo {name}, jepang {weather}",
     "Hello {name}" : "Helo {name}",
     "_download %n file_::_download %n files_" : ["unduh %n berkas"],
-    "{version} is available. Get more information on how to update." : "{version} tersedia. Dapatkan informasi lebih lanjut cara memperbaruinya.",
+    "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "Pembaruan sedang dalam proses, meninggalkan halaman ini mungkin dapat mengganggu proses di beberapa lingkungan.",
     "Updating {productName} to version {version}, this may take a while." : "Memperbarui {productName} ke versi {version}, ini memerlukan waktu.",
+    "An error occurred." : "Terjadi kesalahan.",
     "Please reload the page." : "Silakan muat ulang halaman.",
     "The update was unsuccessful. " : "Pembaruan tidak berhasil.",
     "The update was successful. There were warnings." : "Pembaruan telah berhasil. Terdapat peringatan.",
     "The update was successful. Redirecting you to ownCloud now." : "Pembaruan sukses. Anda akan diarahkan ulang ke ownCloud.",
-    "Couldn't reset password because the token is invalid" : "Tidak dapat menyetel ulang sandi karena token tidak sah",
-    "Couldn't reset password because the token is expired" : "Tidak dapat menyetel ulang sandi karena token telah kadaluarsa",
-    "Couldn't send reset email. Please make sure your username is correct." : "Tidak dapat menyetel ulang email. Mohon pastikan nama pengguna Anda benar.",
-    "Couldn't send reset email because there is no email address for this username. Please contact your administrator." : "Tidak dapat menyetel ulang email karena tidak ada alamat email untuk nama pengguna ini. Silakan hubungi Administrator Anda.",
-    "%s password reset" : "%s sandi disetel ulang",
-    "Use the following link to reset your password: {link}" : "Gunakan tautan berikut untuk menyetel ulang sandi Anda: {link}",
-    "New password" : "Sandi baru",
-    "New Password" : "Sandi Baru",
-    "Reset password" : "Setel ulang sandi",
     "Searching other places" : "Mencari tempat lainnya",
     "No search results in other folders" : "Tidak ada hasil penelusuran didalam folder yang lain",
     "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} hasil pencarian di folder lain"],
@@ -245,6 +238,7 @@ OC.L10N.register(
     "Finishing …" : "Menyelesaikan ...",
     "Need help?" : "Butuh bantuan?",
     "See the documentation" : "Lihat dokumentasi",
+    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Hai,<br><br>hanya memberi tahu jika %s membagikan <strong>%s</strong> dengan Anda.<br><a href=\"%s\">Lihat!</a><br><br>",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Aplikasi ini memerlukan JavaScript untuk dapat beroperasi dengan benar. Mohon {linkstart}aktifkan JavaScript{linkend} dan muat ulang halaman ini.",
     "Log out" : "Keluar",
     "Search" : "Cari",
@@ -254,15 +248,17 @@ OC.L10N.register(
     "Please try again or contact your administrator." : "Mohon coba lagi atau hubungi administrator Anda.",
     "Log in" : "Masuk",
     "Wrong password. Reset it?" : "Sandi salah. Atur ulang?",
-    "remember" : "selalu masuk",
+    "Stay logged in" : "Tetap masuk",
     "Alternative Logins" : "Cara Alternatif untuk Masuk",
-    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Hai,<br><br>hanya memberi tahu jika %s membagikan <strong>%s</strong> dengan Anda.<br><a href=\"%s\">Lihat!</a><br><br>",
+    "Use the following link to reset your password: {link}" : "Gunakan tautan berikut untuk menyetel ulang sandi Anda: {link}",
+    "New password" : "Sandi baru",
+    "New Password" : "Sandi Baru",
+    "Reset password" : "Setel ulang sandi",
     "This ownCloud instance is currently in single user mode." : "ownCloud ini sedang dalam mode pengguna tunggal.",
     "This means only administrators can use the instance." : "Ini berarti hanya administrator yang dapat menggunakan ownCloud.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Hubungi administrator sistem anda jika pesan ini terus muncul atau muncul tiba-tiba.",
     "Thank you for your patience." : "Terima kasih atas kesabaran anda.",
     "You are accessing the server from an untrusted domain." : "Anda mengakses server dari domain yang tidak terpercaya.",
-    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domain\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Mohon hubungi administrator Anda. Jika Anda seorang administrator dari instansi ini, konfigurasikan pengaturan \"trusted_domain\" didalam config/config.php. Contoh konfigurasi talah disediakan didalam config/config.sample.php.",
     "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Tergantung pada konfigurasi Anda, sebagai seorang administrator Anda kemungkinan dapat menggunakan tombol bawah untuk mempercayai domain ini.",
     "Add \"%s\" as trusted domain" : "tambahkan \"%s\" sebagai domain terpercaya",
     "App update required" : "Diperlukan perbarui aplikasi",
@@ -274,6 +270,9 @@ OC.L10N.register(
     "Start update" : "Jalankan pembaruan",
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Untuk menghindari waktu habis dengan instalasi yang lebih besar, Anda bisa menjalankan perintah berikut dari direktori instalasi Anda:",
     "This %s instance is currently in maintenance mode, which may take a while." : "Instansi %s ini sedang dalam modus pemeliharaan, mungkin memerlukan beberapa saat.",
-    "This page will refresh itself when the %s instance is available again." : "Halaman ini akan disegarkan dengan sendiri saat instansi %s tersebut tersedia kembali."
+    "This page will refresh itself when the %s instance is available again." : "Halaman ini akan disegarkan dengan sendiri saat instansi %s tersebut tersedia kembali.",
+    "Error loading file picker template: {error}" : "Kesalahan saat memuat templat berkas pemilih: {error}",
+    "Password can not be changed. Please contact your administrator." : "Sandi tidak dapat diubah. Silakan hubungi administrator Anda",
+    "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Server ini tidak tersambung ke internet. Ini berarti beberapa fitur seperti me-mount penyimpanan eksternal, notifikasi pembaruan atau instalasi aplikasi pihak ketiga tidak akan bekerja. Mengakses berkas secara remote dan mengirim notifikasi email juga tidak bekerja. Kami menyarankan untuk mengaktifkan koneksi internet untuk server ini jika Anda ingin memiliki fitur ini."
 },
 "nplurals=1; plural=0;");
