@@ -2,15 +2,21 @@ OC.L10N.register(
     "core",
     {
     "Couldn't send mail to following users: %s " : "Не можев да пратам порака на следниве корисници: %s",
+    "Preparing update" : "Ја подготвувам надградбата",
     "Turned on maintenance mode" : "Вклучен е модот за одржување",
     "Turned off maintenance mode" : "Ислкучен е модот за одржување",
+    "Maintenance mode is kept active" : "Модот за одржување е уште активен",
+    "Updating database schema" : "Ја надградувам шемата на базата на податоци",
     "Updated database" : "Базата е надградена",
     "Checked database schema update" : "Проверена е шемата за ажурурање на базата на податоци",
     "Checked database schema update for apps" : "Проверена е шемата за ажурурање на базата на податоци за апликации",
     "Updated \"%s\" to %s" : "Ажурирано е \"%s\" во %s",
     "Repair warning: " : "Предупредувања при поправка:",
     "Repair error: " : "Грешка при поправка:",
-    "Following incompatible apps have been disabled: %s" : "Следниве некомпатибилни апликации се оневозможени: %s",
+    "%s (3rdparty)" : "%s (3-та страна)",
+    "%s (incompatible)" : "%s (некомпатибилен)",
+    "Already up to date" : "Веќе ажурирано",
+    "File is too big" : "Датотеката е пре голема",
     "Invalid file provided" : "Дадена е невалидна датотека",
     "No image or file provided" : "Не е доставена фотографија или датотека",
     "Unknown filetype" : "Непознат тип на датотека",
@@ -19,6 +25,8 @@ OC.L10N.register(
     "No crop data provided" : "Не се доставени податоци за сечење",
     "No valid crop data provided" : "Нема валидни податоци за сечење",
     "Crop is not square" : "Сечењето не е правоаголно",
+    "%s password reset" : "%s ресетирање на лозинката",
+    "Couldn't send reset email. Please contact your administrator." : "Не можам да истпратам порака за ресетирање. Ве молам контактирајте го вашиот администратор.",
     "Sunday" : "Недела",
     "Monday" : "Понеделник",
     "Tuesday" : "Вторник",
@@ -33,6 +41,13 @@ OC.L10N.register(
     "Thu." : "Чет.",
     "Fri." : "Пет.",
     "Sat." : "Саб.",
+    "Su" : "Не",
+    "Mo" : "По",
+    "Tu" : "Вт",
+    "We" : "Ср",
+    "Th" : "Че",
+    "Fr" : "Пе",
+    "Sa" : "Са",
     "January" : "Јануари",
     "February" : "Февруари",
     "March" : "Март",
@@ -60,7 +75,6 @@ OC.L10N.register(
     "Settings" : "Подесувања",
     "Saving..." : "Снимам...",
     "seconds ago" : "пред секунди",
-    "Couldn't send reset email. Please contact your administrator." : "Не можам да истпратам порака за ресетирање. Ве молам контактирајте го вашиот администратор.",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Врската за ресетирање на вашата лозинка е испратена на вашата е-адреса. Ако не ја добиете во разумно време, проверете ги вашите папки за спам/ѓубре.<br>Ако не е таму прашајте го вашиот локален администратор.",
     "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Вашите датотеки се шифрирани. Ако не сте го овозможиле клучот за враќање, нема да можете да ги повратите вашите податоци откога вашата лозинка ќе биде ресетирана.<br>Ако не сте сигурни што да правите, ве молам контактирајте го вашиот локален администратор пред да продолжите.<br/>Дали навистина сакате да продолжите?",
     "I know what I'm doing" : "Знам што правам",
@@ -89,54 +103,62 @@ OC.L10N.register(
     "Strong password" : "Јака лозинка",
     "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Вашиот веб опслужувач сеуште не е точно подесен да овозможува синхронизација на датотеки бидејќи интерфејсот за WebDAV изгледа дека е расипан. ",
     "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Овој опслужувач нема работна Интернет врска. Ова значи дека некои опции како што е монтирање на надворешни складишта, известувања за ажурирање или инсталации на апликации од 3-ти лица нема да работат. Пристапот на датотеки од далечина и праќање на пораки за известувања може исто така да не работат. Ви советуваме да овозможите Интернет врска за овој опслужувач ако сакате да ги имате сите опции. ",
-    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Вашата папка за податоци и вашите датотеки се најверојатно достапни од интернет. Датотеката .htaccess не работи. Строго ви препорачуваме да го подесите вашиот веб опслужувач на начин на кој вашата папка за податоци не е веќе достапна од интернет или да ја преместите папката за податоци надвор од коренот на веб опслужувачот.",
-    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a href=\"{docLink}\">documentation</a>." : "Не  еконфигуриран кеш за меморијата. За да ги подобрите перформансите ве молам конфигурирајте memcache ако е достапно. Дополнителни информации можат да се најдат во нашата  <a href=\"{docLink}\">документација</a>.",
     "Error occurred while checking server setup" : "Се случи грешка при проверката на подесувањата на опслужувачот",
+    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Вашата папка за податоци и вашите датотеки се најверојатно достапни од интернет. Датотеката .htaccess не работи. Строго ви препорачуваме да го подесите вашиот веб опслужувач на начин на кој вашата папка за податоци не е веќе достапна од интернет или да ја преместите папката за податоци надвор од коренот на веб опслужувачот.",
     "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "HTTP заглавието \"{header}\" не е конфигурирано да биде еднакво на \"{expected}\". Ова е потенцијално сигурносен ризик и препорачуваме да прилагодат подесувањата.",
     "Shared" : "Споделен",
     "Shared with {recipients}" : "Споделено со {recipients}",
     "Error" : "Грешка",
     "Error while sharing" : "Грешка при споделување",
     "Error while unsharing" : "Грешка при прекин на споделување",
-    "Error while changing permissions" : "Грешка при промена на привилегии",
     "Error setting expiration date" : "Грешка при поставување на рок на траење",
     "Set expiration date" : "Постави рок на траење",
     "Expiration" : "Истекување",
     "Expiration date" : "Рок на траење",
+    "Choose a password for the public link" : "Одбери лозинка за јавниот линк",
     "Sending ..." : "Праќање...",
     "Email sent" : "Е-порака пратена",
     "Resharing is not allowed" : "Повторно споделување не е дозволено",
     "Share link" : "Сподели ја врската",
+    "Link" : "Линк",
     "Password protect" : "Заштити со лозинка",
     "Password" : "Лозинка",
+    "Allow editing" : "Овозможи уредување",
     "Email link to person" : "Прати врска по е-пошта на личност",
     "Send" : "Прати",
     "Shared with you and the group {group} by {owner}" : "Споделено со Вас и групата {group} од {owner}",
     "Shared with you by {owner}" : "Споделено со Вас од {owner}",
-    "Shared in {item} with {user}" : "Споделено во {item} со {user}",
     "group" : "група",
+    "remote" : "далечински",
     "notify by email" : "извести преку електронска пошта",
     "Unshare" : "Не споделувај",
     "can share" : "може да споделува",
     "can edit" : "може да се измени",
     "create" : "креирај",
+    "change" : "промени",
     "delete" : "избриши",
     "access control" : "контрола на пристап",
+    "An error occured. Please try again" : "Се случи грешка. Обиди се повторно",
     "Share" : "Сподели",
     "Share with users or groups …" : "Сподели со корисници или групи ...",
     "Share with users, groups or remote users …" : "Споделено со корисници, групи или оддалечени корисници ...",
     "Warning" : "Предупредување",
+    "not assignable" : "не може да се додаде",
+    "invisible" : "невидлив",
+    "Delete" : "Избриши",
+    "Rename" : "Преименувај",
     "The object type is not specified." : "Не е специфициран типот на објект.",
     "Enter new" : "Внеси нов",
-    "Delete" : "Избриши",
     "Add" : "Додади",
     "Edit tags" : "Уреди ги таговите",
     "No tags selected for deletion." : "Не се селектирани тагови за бришење.",
+    "unknown text" : "непознат текст",
+    "Hello world!" : "Здраво свету!",
+    "sunny" : "сончево",
+    "Hello {name}" : "Здраво {name}",
+    "_download %n file_::_download %n files_" : ["преземи %n датотеки","преземи %n датотеки"],
+    "An error occurred." : "Се случи грешка",
     "The update was successful. Redirecting you to ownCloud now." : "Надградбата беше успешна. Веднаш ве префрлам на вашиот ownCloud.",
-    "%s password reset" : "%s ресетирање на лозинката",
-    "Use the following link to reset your password: {link}" : "Користете ја следната врска да ја ресетирате Вашата лозинка: {link}",
-    "New password" : "Нова лозинка",
-    "Reset password" : "Ресетирај лозинка",
     "Personal" : "Лично",
     "Users" : "Корисници",
     "Apps" : "Аппликации",
@@ -149,28 +171,53 @@ OC.L10N.register(
     "Error untagging" : "Грешка при отстранување на таговите",
     "Error favoriting" : "Грешка при ",
     "Access forbidden" : "Забранет пристап",
+    "File not found" : "Датотеката не е пронајдена",
     "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Здраво,\n\nСамо да ве известам дека  %s shared %s with you.\nView it: %s\n\n",
     "Cheers!" : "Поздрав!",
+    "Internal Server Error" : "Интерна серверска грешка",
+    "Technical details" : "Технички детали",
+    "Type: %s" : "Тип: %s",
+    "Code: %s" : "Код: %s",
+    "Message: %s" : "Порака: %s",
+    "File: %s" : "Датотека: %s",
+    "Line: %s" : "Линија: %s",
+    "Security warning" : "Безбедносно предупредување",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Вашиот директориум со податоци и датотеки се веројатно достапни преку интенернт поради што .htaccess датотеката не функционира.",
     "Create an <strong>admin account</strong>" : "Направете <strong>администраторска сметка</strong>",
     "Username" : "Корисничко име",
     "Data folder" : "Фолдер со податоци",
     "Configure the database" : "Конфигурирај ја базата",
+    "Only %s is available." : "Само %s е достапно.",
     "Database user" : "Корисник на база",
     "Database password" : "Лозинка на база",
     "Database name" : "Име на база",
     "Database tablespace" : "Табела во базата на податоци",
     "Database host" : "Сервер со база",
+    "Performance warning" : "Предупредување за перформансите",
+    "SQLite will be used as database." : "SQLite ќе се користи како база на податоци.",
     "Finish setup" : "Заврши го подесувањето",
     "Finishing …" : "Завршувам ...",
+    "Need help?" : "Ви треба помош?",
+    "See the documentation" : "Види ја документацијата",
     "Log out" : "Одјава",
     "Search" : "Барај",
     "Server side authentication failed!" : "Автентификацијата на серверската страна е неуспешна!",
     "Please contact your administrator." : "Ве молиме контактирајте го вашиот администратор.",
+    "An internal error occured." : "Се случи интерна грешка",
     "Log in" : "Најава",
-    "remember" : "запамти",
+    "Wrong password. Reset it?" : "Погрешна лозинка. Да ја ресетирам?",
+    "Wrong password." : "Погрешна лозинка.",
+    "Stay logged in" : "Остани најаваен",
     "Alternative Logins" : "Алтернативни најавувања",
+    "Use the following link to reset your password: {link}" : "Користете ја следната врска да ја ресетирате Вашата лозинка: {link}",
+    "New password" : "Нова лозинка",
+    "New Password" : "Нова лозинка",
+    "Reset password" : "Ресетирај лозинка",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Контактирајте го вашиот систем администратор до колку оваа порака продолжи да се појавува или пак се појавува ненадејно.",
-    "Thank you for your patience." : "Благодариме на вашето трпение."
+    "Thank you for your patience." : "Благодариме на вашето трпение.",
+    "These apps will be updated:" : "Следните апликации чќе бидат надградени:",
+    "Start update" : "Започни ја надградбата",
+    "Error loading file picker template: {error}" : "Грешка при вчитување на образецот за одбирач на датотеки: {error}",
+    "Password can not be changed. Please contact your administrator." : "Лозинката не може да се промени. Ве молам контактирајте го вашиот администратор."
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
