@@ -59,7 +59,6 @@ OC.L10N.register(
     "App can't be installed because of not allowed code in the App" : "Appen kan ikke installeres, da den indeholder ikke-tilladt kode",
     "App can't be installed because it is not compatible with this version of ownCloud" : "Appen kan ikke installeres, da den ikke er kompatibel med denne version af ownCloud.",
     "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "Appen kan ikke installeres, da den indeholder mærket <shipped>true</shipped>, hvilket ikke er tilladt for ikke-medfølgende apps",
-    "App can't be installed because the version in info.xml/version is not the same as the version reported from the app store" : "App kan ikke installeres, da versionen i info.xml/version ikke er den samme som versionen rapporteret fra app-storen",
     "Application is not enabled" : "Programmet er ikke aktiveret",
     "Authentication error" : "Adgangsfejl",
     "Token expired. Please reload page." : "Adgang er udløbet. Genindlæs siden.",
@@ -87,7 +86,7 @@ OC.L10N.register(
     "Sharing %s failed, because the backend does not allow shares from type %i" : "Deling af %s mislykkedes, fordi backenden ikke tillader delinger fra typen %i",
     "Sharing %s failed, because the file does not exist" : "Deling af %s mislykkedes, fordi filen ikke eksisterer",
     "You are not allowed to share %s" : "Du har ikke tilladelse til at dele %s",
-    "Sharing %s failed, because the user %s is the item owner" : "Der skete en fejl ved deling af %s, brugeren %s er ejer af objektet",
+    "Sharing %s failed, because you can not share with yourself" : "Deling af %s mislykkedes, fordi du ikke kan dele med dig selv",
     "Sharing %s failed, because the user %s does not exist" : "Der skete en fejl ved deling af %s, brugeren %s eksistere ikke",
     "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Der skete en fejl ved deling af %s, brugeren %s er ikke medlem af nogle grupper som %s er medlem af",
     "Sharing %s failed, because this item is already shared with %s" : "Der skete en fejl ved deling af %s, objektet er allerede delt med %s",
@@ -106,14 +105,13 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Delingsbackend'en %s skal implementere grænsefladen OCP\\Share_Backend",
     "Sharing backend %s not found" : "Delingsbackend'en %s blev ikke fundet",
     "Sharing backend for %s not found" : "Delingsbackend'en for %s blev ikke fundet",
-    "Sharing %s failed, because the user %s is the original sharer" : "Deling af %s mislykkedes, fordi brugeren %s er den som delte oprindeligt",
+    "Sharing failed, because the user %s is the original sharer" : "Deling mislykkedes, fordi brugeren %s er den som delte oprindeligt",
     "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Deling af %s mislykkedes, fordi tilladelserne overskred de tillaldelser som %s var tildelt",
     "Sharing %s failed, because resharing is not allowed" : "Deling af %s mislykkedes, fordi videredeling ikke er tilladt",
     "Sharing %s failed, because the sharing backend for %s could not find its source" : "Deling af %s mislykkedes, fordi back-enden ikke kunne finde kilden til %s",
     "Sharing %s failed, because the file could not be found in the file cache" : "Deling af %s mislykkedes, fordi filen ikke kunne findes i fil-cachen",
     "Could not find category \"%s\"" : "Kunne ikke finde kategorien \"%s\"",
     "Apps" : "Apps",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-\"" : "Det er kun tilladt at benytte følgene karakterer i et brugernavn \"a-z\", \"A-Z\", \"0-9\", and \"_.@-\"",
     "A valid username must be provided" : "Et gyldigt brugernavn skal angives",
     "A valid password must be provided" : "En gyldig adgangskode skal angives",
     "The username is already being used" : "Brugernavnet er allerede i brug",
@@ -140,14 +138,13 @@ OC.L10N.register(
     "Please ask your server administrator to restart the web server." : "Du bedes anmode din serveradministrator om at genstarte webserveren.",
     "PostgreSQL >= 9 required" : "PostgreSQL >= 9 kræves",
     "Please upgrade your database version" : "Opgradér venligst din databaseversion",
-    "Error occurred while checking PostgreSQL version" : "Der opstod fejl under tjek af PostgreSQL-versionen",
-    "Please make sure you have PostgreSQL >= 9 or check the logs for more information about the error" : "Sørg venligst for at du har PostgreSQL >= 9 eller tjek loggen for flere informationer om fejlen",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Tilpas venligst rettigheder til 0770, så mappen ikke fremvises for andre brugere.",
     "Data directory (%s) is readable by other users" : "Datamappen (%s) kan læses af andre brugere",
     "Data directory (%s) must be an absolute path" : "Datamappen (%s) skal have en absolut sti",
     "Check the value of \"datadirectory\" in your configuration" : "Tjek værdien for \"databibliotek\" i din konfiguration",
     "Data directory (%s) is invalid" : "Datamappen (%s) er ugyldig",
     "Please check that the data directory contains a file \".ocdata\" in its root." : "Tjek venligst at datamappen indeholder en fil, \".ocdata\" i dens rod.",
-    "Could not obtain lock type %d on \"%s\"." : "Kunne ikke opnå en låsetype %d på \"%s\"."
+    "Could not obtain lock type %d on \"%s\"." : "Kunne ikke opnå en låsetype %d på \"%s\".",
+    "Storage not available" : "Lagerplads er ikke tilgængeligt"
 },
 "nplurals=2; plural=(n != 1);");
