@@ -49,6 +49,9 @@ class ActivityManager implements IManager {
 	/** @var int */
 	protected $formattingObjectId;
 
+	/** @var string */
+	protected $currentUserId;
+
 	/**
 	 * constructor of the controller
 	 *
@@ -256,11 +259,11 @@ class ActivityManager implements IManager {
 		foreach ($this->getExtensions() as $c) {
 			$result = $c->getNotificationTypes($languageCode);
 			if (is_array($result)) {
-				if (class_exists('\OCA\Files\Activity') && $c instanceof \OCA\Files\Activity) {
+				if (class_exists('\OCA\Files\Activity', false) && $c instanceof \OCA\Files\Activity) {
 					$filesNotificationTypes = $result;
 					continue;
 				}
-				if (class_exists('\OCA\Files_Sharing\Activity') && $c instanceof \OCA\Files_Sharing\Activity) {
+				if (class_exists('\OCA\Files_Sharing\Activity', false) && $c instanceof \OCA\Files_Sharing\Activity) {
 					$sharingNotificationTypes = $result;
 					continue;
 				}
@@ -321,7 +324,8 @@ class ActivityManager implements IManager {
 	 * @return bool
 	 */
 	public function isFormattingFilteredObject() {
-		return $this->formattingObjectType === $this->request->getParam('object_type')
+		return $this->formattingObjectType !== null && $this->formattingObjectId !== null
+			&& $this->formattingObjectType === $this->request->getParam('object_type')
 			&& $this->formattingObjectId === $this->request->getParam('object_id');
 	}
 
@@ -474,6 +478,19 @@ class ActivityManager implements IManager {
 		return array(' and ((' . implode(') or (', $conditions) . '))', $parameters);
 	}
 
+	/**
+	 * Set the user we need to use
+	 *
+	 * @param string|null $currentUserId
+	 * @throws \UnexpectedValueException If the user is invalid
+	 */
+	public function setCurrentUserId($currentUserId) {
+		if (!is_string($currentUserId) && $currentUserId !== null) {
+			throw new \UnexpectedValueException('The given current user is invalid');
+		}
+		$this->currentUserId = $currentUserId;
+	}
+
 	/**
 	 * Get the user we need to use
 	 *
@@ -483,7 +500,9 @@ class ActivityManager implements IManager {
 	 * @throws \UnexpectedValueException If the token is invalid, does not exist or is not unique
 	 */
 	public function getCurrentUserId() {
-		if (!$this->session->isLoggedIn()) {
+		if ($this->currentUserId !== null) {
+			return $this->currentUserId;
+		} else if (!$this->session->isLoggedIn()) {
 			return $this->getUserFromToken();
 		} else {
 			return $this->session->getUser()->getUID();
