@@ -3,9 +3,8 @@
  * @author Bart Visscher <bartv@thisnet.nl>
  * @author Georg Ehrke <georg@owncloud.com>
  * @author Lukas Reschke <lukas@owncloud.com>
- * @author Thomas Müller <thomas.mueller@tmit.eu>
  *
- * @copyright Copyright (c) 2015, ownCloud, Inc.
+ * @copyright Copyright (c) 2016, ownCloud, Inc.
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -27,11 +26,20 @@ OCP\JSON::callCheck();
 $username = (string)$_POST['username'];
 $group = (string)$_POST['group'];
 
+$subAdminManager = \OC::$server->getGroupManager()->getSubAdmin();
+$targetUserObject = \OC::$server->getUserManager()->get($username);
+$targetGroupObject = \OC::$server->getGroupManager()->get($group);
+
+$isSubAdminOfGroup = false;
+if($targetUserObject !== null && $targetUserObject !== null) {
+	$isSubAdminOfGroup = $subAdminManager->isSubAdminofGroup($targetUserObject, $targetGroupObject);
+}
+
 // Toggle group
-if(OC_SubAdmin::isSubAdminofGroup($username, $group)) {
-	OC_SubAdmin::deleteSubAdmin($username, $group);
-}else{
-	OC_SubAdmin::createSubAdmin($username, $group);
+if($isSubAdminOfGroup) {
+	$subAdminManager->deleteSubAdmin($targetUserObject, $targetGroupObject);
+} else {
+	$subAdminManager->createSubAdmin($targetUserObject, $targetGroupObject);
 }
 
 OC_JSON::success();
