@@ -1,6 +1,8 @@
 OC.L10N.register(
     "settings",
     {
+    "APCu" : "APCu",
+    "Redis" : "Redis",
     "Security & setup warnings" : "Security & setup warnings",
     "Sharing" : "Sharing",
     "Server-side encryption" : "Server-side encryption",
@@ -10,12 +12,10 @@ OC.L10N.register(
     "Log" : "Log",
     "Tips & tricks" : "Tips & tricks",
     "Updates" : "Updates",
-    "Authentication error" : "Authentication error",
-    "Your full name has been changed." : "Your full name has been changed.",
-    "Unable to change full name" : "Unable to change full name",
     "Couldn't remove app." : "Couldn't remove app.",
     "Language changed" : "Language changed",
     "Invalid request" : "Invalid request",
+    "Authentication error" : "Authentication error",
     "Admins can't remove themself from the admin group" : "Admins can't remove themselves from the admin group",
     "Unable to add user to group %s" : "Unable to add user to group %s",
     "Unable to remove user from group %s" : "Unable to remove user from group %s",
@@ -28,7 +28,9 @@ OC.L10N.register(
     "Unable to change password" : "Unable to change password",
     "Enabled" : "Enabled",
     "Not enabled" : "Not enabled",
+    "installing and updating apps via the app store or Federated Cloud Sharing" : "installing and updating apps via the app store or Federated Cloud Sharing",
     "Federated Cloud Sharing" : "Federated Cloud Sharing",
+    "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably.",
     "A problem occurred, please check your log files (Error: %s)" : "A problem occurred, please check your log files (Error: %s)",
     "Migration Completed" : "Migration Completed",
     "Group already exists." : "Group already exists.",
@@ -49,6 +51,8 @@ OC.L10N.register(
     "Invalid user" : "Invalid user",
     "Unable to change mail address" : "Unable to change mail address",
     "Email saved" : "Email saved",
+    "Your full name has been changed." : "Your full name has been changed.",
+    "Unable to change full name" : "Unable to change full name",
     "Are you really sure you want add \"{domain}\" as trusted domain?" : "Are you really sure you want add \"{domain}\" as a trusted domain?",
     "Add trusted domain" : "Add trusted domain",
     "Migration in progress. Please wait until the migration is finished" : "Migration in progress. Please wait until the migration is finished",
@@ -58,9 +62,12 @@ OC.L10N.register(
     "Approved" : "Approved",
     "Experimental" : "Experimental",
     "All" : "All",
+    "No apps found for your version" : "No apps found for your version",
     "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use.",
     "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use.",
+    "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "This app is not checked for security issues and is new or known to be unstable. Install at your own risk.",
     "Update to %s" : "Update to %s",
+    "_You have %n app update pending_::_You have %n app updates pending_" : ["You have %n app update pending","You have %n app updates pending"],
     "Please wait...." : "Please wait....",
     "Error while disabling app" : "Error whilst disabling app",
     "Disable" : "Disable",
@@ -72,18 +79,22 @@ OC.L10N.register(
     "Uninstalling ...." : "Uninstalling...",
     "Error while uninstalling app" : "Error whilst uninstalling app",
     "Uninstall" : "Uninstall",
+    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds.",
+    "App update" : "App update",
+    "No apps found for \"{query}\"" : "No apps found for \"{query}\"",
+    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "An error occurred. Please upload an ASCII-encoded PEM certificate.",
+    "Valid until {date}" : "Valid until {date}",
+    "Delete" : "Delete",
+    "An error occurred: {message}" : "An error occurred: {message}",
     "Select a profile picture" : "Select a profile picture",
     "Very weak password" : "Very weak password",
     "Weak password" : "Weak password",
     "So-so password" : "So-so password",
     "Good password" : "Good password",
     "Strong password" : "Strong password",
-    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "An error occurred. Please upload an ASCII-encoded PEM certificate.",
-    "Valid until {date}" : "Valid until {date}",
-    "Delete" : "Delete",
     "Groups" : "Groups",
     "Unable to delete {objName}" : "Unable to delete {objName}",
-    "Error creating group" : "Error creating group",
+    "Error creating group: {message}" : "Error creating group: {message}",
     "A valid group name must be provided" : "A valid group name must be provided",
     "deleted {groupName}" : "deleted {groupName}",
     "undo" : "undo",
@@ -93,13 +104,12 @@ OC.L10N.register(
     "add group" : "add group",
     "Changing the password will result in data loss, because data recovery is not available for this user" : "Changing the password will result in data loss, because data recovery is not available for this user",
     "A valid username must be provided" : "A valid username must be provided",
-    "Error creating user" : "Error creating user",
+    "Error creating user: {message}" : "Error creating user: {message}",
     "A valid password must be provided" : "A valid password must be provided",
     "A valid email must be provided" : "A valid email must be provided",
     "__language_name__" : "English (British English)",
-    "Sync clients" : "Sync clients",
     "Personal info" : "Personal info",
-    "SSL root certificates" : "SSL root certificates",
+    "Sync clients" : "Sync clients",
     "Everything (fatal issues, errors, warnings, info, debug)" : "Everything (fatal issues, errors, warnings, info, debug)",
     "Info, warnings, errors and fatal issues" : "Info, warnings, errors and fatal issues",
     "Warnings, errors and fatal issues" : "Warnings, errors and fatal issues",
@@ -112,17 +122,21 @@ OC.L10N.register(
     "SSL" : "SSL",
     "TLS" : "TLS",
     "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response.",
+    "Please check the <a target=\"_blank\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Please check the <a target=\"_blank\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm.",
     "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update.",
     "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator.",
     "Your server is running on Microsoft Windows. We highly recommend Linux for optimal user experience." : "Your server is running on Microsoft Windows. We highly recommend Linux for optimal user experience.",
+    "%1$s below version %2$s is installed, for stability and performance reasons we recommend updating to a newer %1$s version." : "%1$s below version %2$s is installed, for stability and performance reasons we recommend updating to a newer %1$s version.",
     "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "The PHP module 'fileinfo' is missing. We strongly recommend enabling this module to get best results with mime-type detection.",
+    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" href=\"%s\">documentation ↗</a> for more information." : "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" href=\"%s\">documentation ↗</a> for more information.",
     "System locale can not be set to a one which supports UTF-8." : "System locale can not be set to a one which supports UTF-8.",
     "This means that there might be problems with certain characters in file names." : "This means that there might be problems with certain characters in file names.",
     "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "We strongly suggest installing the required packages on your system to support one of the following locales: %s.",
     "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")",
     "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:",
     "Please double check the <a target=\"_blank\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Please double check the <a target=\"_blank\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>.",
+    "All checks passed." : "All checks passed.",
     "Open documentation" : "Open documentation",
     "Allow apps to use the Share API" : "Allow apps to use the Share API",
     "Allow users to share via link" : "Allow users to share via link",
@@ -138,6 +152,7 @@ OC.L10N.register(
     "Allow users to send mail notification for shared files to other users" : "Allow users to send email notification for shared files to other users",
     "Exclude groups from sharing" : "Exclude groups from sharing",
     "These groups will still be able to receive shares, but not to initiate them." : "These groups will still be able to receive shares, but not to initiate them.",
+    "Allow username autocompletion in share dialog. If this is disabled the full username needs to be entered." : "Allow username autocompletion in share dialog. If this is disabled the full username needs to be entered.",
     "Last cron job execution: %s." : "Last cron job execution: %s.",
     "Last cron job execution: %s. Something seems wrong." : "Last cron job execution: %s. Something seems wrong.",
     "Cron was not executed yet!" : "Cron was not executed yet!",
@@ -145,6 +160,12 @@ OC.L10N.register(
     "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php is registered at a webcron service to call cron.php every 15 minutes over http.",
     "Use system's cron service to call the cron.php file every 15 minutes." : "Use system's cron service to call the cron.php file every 15 minutes.",
     "Enable server-side encryption" : "Enable server-side encryption",
+    "Please read carefully before activating server-side encryption: " : "Please read carefully before activating server-side encryption: ",
+    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met.",
+    "Encryption alone does not guarantee security of the system. Please see ownCloud documentation for more information about how the encryption app works, and the supported use cases." : "Encryption alone does not guarantee security of the system. Please see ownCloud documentation for more information about how the encryption app works, and the supported use cases.",
+    "Be aware that encryption always increases the file size." : "Be aware that encryption always increases the file size.",
+    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data.",
+    "This is the final warning: Do you really want to enable encryption?" : "This is the final warning: Do you really want to enable encryption?",
     "Enable encryption" : "Enable encryption",
     "No encryption module loaded, please enable an encryption module in the app menu." : "No encryption module loaded, please enable an encryption module in the app menu.",
     "Select default encryption module:" : "Select default encryption module:",
@@ -166,11 +187,11 @@ OC.L10N.register(
     "Store credentials" : "Store credentials",
     "Test email settings" : "Test email settings",
     "Send email" : "Send email",
-    "Log level" : "Log level",
     "Download logfile" : "Download logfile",
     "More" : "More",
     "Less" : "Less",
     "The logfile is bigger than 100 MB. Downloading it may take some time!" : "The logfile is larger than 100 MB. Downloading it may take some time!",
+    "What to log" : "What to log",
     "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "SQLite is used as database. For larger installations, we recommend you switch to a different database backend.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Especially when using the desktop client for file syncing, the use of SQLite is discouraged.",
     "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" href=\"%s\">documentation ↗</a>." : "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" href=\"%s\">documentation ↗</a>.",
@@ -184,17 +205,26 @@ OC.L10N.register(
     "Developer documentation" : "Developer documentation",
     "Experimental applications ahead" : "Experimental applications ahead",
     "Experimental apps are not checked for security issues, new or known to be unstable and under heavy development. Installing them can cause data loss or security breaches." : "Experimental apps are not checked for security issues, new or known to be unstable and under heavy development. Installing them can cause data loss or security breaches.",
-    "by" : "by",
-    "licensed" : "licensed",
+    "by %s" : "by %s",
+    "%s-licensed" : "%s-licensed",
     "Documentation:" : "Documentation:",
     "User documentation" : "User documentation",
+    "Admin documentation" : "Admin documentation",
     "Show description …" : "Show description …",
     "Hide description …" : "Hide description …",
+    "This app has an update available." : "This app has an update available.",
+    "This app has no minimum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "This app has no minimum ownCloud version assigned. This will be an error in ownCloud 11 and later.",
+    "This app has no maximum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "This app has no maximum ownCloud version assigned. This will be an error in ownCloud 11 and later.",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "This app cannot be installed because the following dependencies are not fulfilled:",
     "Enable only for specific groups" : "Enable only for specific groups",
     "Uninstall App" : "Uninstall App",
     "Enable experimental apps" : "Enable experimental apps",
-    "No apps found for your version" : "No apps found for your version",
+    "SSL Root Certificates" : "SSL Root Certificates",
+    "Common Name" : "Common Name",
+    "Valid until" : "Valid until",
+    "Issued By" : "Issued By",
+    "Valid until %s" : "Valid until %s",
+    "Import root certificate" : "Import root certificate",
     "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>",
     "Cheers!" : "Cheers!",
     "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n",
@@ -203,39 +233,35 @@ OC.L10N.register(
     "Forum" : "Forum",
     "Issue tracker" : "Issue tracker",
     "Commercial support" : "Commercial support",
+    "You are using <strong>%s</strong> of <strong>%s</strong>" : "You are using <strong>%s</strong> of <strong>%s</strong>",
+    "Profile picture" : "Profile picture",
+    "Upload new" : "Upload new",
+    "Select from Files" : "Select from Files",
+    "Remove image" : "Remove image",
+    "png or jpg, max. 20 MB" : "png or jpg, max. 20 MB",
+    "Picture provided by original account" : "Picture provided by original account",
+    "Cancel" : "Cancel",
+    "Choose as profile picture" : "Choose as profile picture",
+    "Full name" : "Full name",
+    "No display name set" : "No display name set",
+    "Email" : "Email",
+    "Your email address" : "Your email address",
+    "For password recovery and notifications" : "For password recovery and notifications",
+    "No email address set" : "No email address set",
+    "You are member of the following groups:" : "You are member of the following groups:",
+    "Password" : "Password",
+    "Unable to change your password" : "Unable to change your password",
+    "Current password" : "Current password",
+    "New password" : "New password",
+    "Change password" : "Change password",
+    "Language" : "Language",
+    "Help translate" : "Help translate",
     "Get the apps to sync your files" : "Get the apps to sync your files",
     "Desktop client" : "Desktop client",
     "Android app" : "Android app",
     "iOS app" : "iOS app",
     "If you want to support the project\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\tor\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "If you want to support the project\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\tor\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!",
     "Show First Run Wizard again" : "Show First Run Wizard again",
-    "You have used <strong>%s</strong> of the available <strong>%s</strong>" : "You have used <strong>%s</strong> of the available <strong>%s</strong>",
-    "Password" : "Password",
-    "Unable to change your password" : "Unable to change your password",
-    "Current password" : "Current password",
-    "New password" : "New password",
-    "Change password" : "Change password",
-    "Full name" : "Full name",
-    "No display name set" : "No display name set",
-    "Email" : "Email",
-    "Your email address" : "Your email address",
-    "Fill in an email address to enable password recovery and receive notifications" : "Fill in an email address to enable password recovery and receive notifications",
-    "No email address set" : "No email address set",
-    "You are member of the following groups:" : "You are member of the following groups:",
-    "Profile picture" : "Profile picture",
-    "Upload new" : "Upload new",
-    "Select new from Files" : "Select new from Files",
-    "Remove image" : "Remove image",
-    "Your avatar is provided by your original account." : "Your avatar is provided by your original account.",
-    "Cancel" : "Cancel",
-    "Choose as profile image" : "Choose as profile image",
-    "Language" : "Language",
-    "Help translate" : "Help translate",
-    "Common Name" : "Common Name",
-    "Valid until" : "Valid until",
-    "Issued By" : "Issued By",
-    "Valid until %s" : "Valid until %s",
-    "Import root certificate" : "Import root certificate",
     "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public Licence\">AGPL</abbr>{linkclose}.",
     "Show storage location" : "Show storage location",
     "Show last log in" : "Show last log in",
