@@ -12,12 +12,10 @@ OC.L10N.register(
     "Log" : "Log",
     "Tips & tricks" : "Trucs et astuces",
     "Updates" : "Mises à jour",
-    "Authentication error" : "Erreur d'authentification",
-    "Your full name has been changed." : "Votre nom complet a été modifié.",
-    "Unable to change full name" : "Impossible de changer le nom complet",
     "Couldn't remove app." : "Impossible de supprimer l'application.",
     "Language changed" : "Langue changée",
     "Invalid request" : "Requête non valide",
+    "Authentication error" : "Erreur d'authentification",
     "Admins can't remove themself from the admin group" : "Les administrateurs ne peuvent pas se retirer eux-mêmes du groupe admin",
     "Unable to add user to group %s" : "Impossible d'ajouter l'utilisateur au groupe %s",
     "Unable to remove user from group %s" : "Impossible de supprimer l'utilisateur du groupe %s",
@@ -40,7 +38,7 @@ OC.L10N.register(
     "Unable to delete group." : "Impossible de supprimer le groupe.",
     "log-level out of allowed range" : "niveau de journalisation hors borne",
     "Saved" : "Sauvegardé",
-    "test email settings" : "tester les paramètres e-mail",
+    "test email settings" : "Test des paramètres e-mail",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Une erreur est survenue lors de l'envoi de l'e-mail. Veuillez vérifier vos paramètres. (Erreur: %s)",
     "Email sent" : "E-mail envoyé",
     "You need to set your user email before being able to send test emails." : "Vous devez définir une adresse e-mail dans vos paramètres personnels avant de pouvoir envoyer des e-mails de test.",
@@ -53,6 +51,8 @@ OC.L10N.register(
     "Invalid user" : "Utilisateur non valable",
     "Unable to change mail address" : "Impossible de modifier l'adresse e-mail",
     "Email saved" : "E-mail sauvegardé",
+    "Your full name has been changed." : "Votre nom complet a été modifié.",
+    "Unable to change full name" : "Impossible de changer le nom complet",
     "Are you really sure you want add \"{domain}\" as trusted domain?" : "Êtes-vous vraiment sûr de vouloir ajouter \"{domain}\" comme domaine de confiance ?",
     "Add trusted domain" : "Ajouter un domaine de confiance",
     "Migration in progress. Please wait until the migration is finished" : "Migration en cours. Veuillez attendre que celle-ci se termine",
@@ -62,6 +62,7 @@ OC.L10N.register(
     "Approved" : "Approuvée",
     "Experimental" : "Expérimentale",
     "All" : "Tous",
+    "No apps found for your version" : "Pas d'application trouvée pour votre version",
     "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "Les applications officielles sont développées par et avec la communauté ownCloud. Elles permettent à ownCloud d'offrir ses fonctionnalités principales et sont prêtes pour une utilisation en environnement de production. ",
     "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Les applications approuvées sont créées par des développeurs de confiance et ont passé les tests de sécurité. Elles sont activement maintenues et leur code source est ouvert. Leurs développeurs les considèrent stables pour une utilisation normale.",
     "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Cette application est nouvelle ou instable, et sa sécurité n'a pas été vérifiée. Installez-la à vos risques et périls!",
@@ -77,7 +78,12 @@ OC.L10N.register(
     "Uninstalling ...." : "Désinstallation...",
     "Error while uninstalling app" : "Erreur lors de la désinstallation de l'application",
     "Uninstall" : "Désinstaller",
+    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "L'application a été activée mais doit être mise à jour. Vous allez être redirigé vers la page des mises à jour dans 5 secondes.",
     "App update" : "Mise à jour",
+    "No apps found for \"{query}\"" : "Aucune application trouvée pour \"{query}\"",
+    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Une erreur est survenue. Veuillez fournir un certificat PEM encodé au format ASCII.",
+    "Valid until {date}" : "Valide jusqu'au {date}",
+    "Delete" : "Supprimer",
     "An error occurred: {message}" : "Une erreur est survenue : {message}",
     "Select a profile picture" : "Selectionnez une photo de profil ",
     "Very weak password" : "Mot de passe de très faible sécurité",
@@ -85,12 +91,9 @@ OC.L10N.register(
     "So-so password" : "Mot de passe de sécurité tout juste acceptable",
     "Good password" : "Mot de passe de sécurité suffisante",
     "Strong password" : "Mot de passe de forte sécurité",
-    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Une erreur est survenue. Veuillez fournir un certificat PEM encodé au format ASCII.",
-    "Valid until {date}" : "Valide jusqu'au {date}",
-    "Delete" : "Supprimer",
     "Groups" : "Groupes",
     "Unable to delete {objName}" : "Impossible de supprimer {objName}",
-    "Error creating group" : "Erreur lors de la création du groupe",
+    "Error creating group: {message}" : "Erreur lors de la création du groupe : {message}",
     "A valid group name must be provided" : "Vous devez spécifier un nom de groupe valide",
     "deleted {groupName}" : "{groupName} supprimé",
     "undo" : "annuler",
@@ -100,13 +103,11 @@ OC.L10N.register(
     "add group" : "ajouter un groupe",
     "Changing the password will result in data loss, because data recovery is not available for this user" : "La modification du mot de passe entrainera la perte des données car la restauration de données n'est pas disponible pour cet utilisateur",
     "A valid username must be provided" : "Un nom d'utilisateur valide doit être saisi",
-    "Error creating user" : "Erreur lors de la création de l'utilisateur",
     "A valid password must be provided" : "Un mot de passe valide doit être saisi",
     "A valid email must be provided" : "Vous devez fournir une adresse e-mail valide",
     "__language_name__" : "Français",
-    "Sync clients" : "Clients de synchronisation",
     "Personal info" : "Informations personnelles",
-    "SSL root certificates" : "Certificats racine SSL",
+    "Sync clients" : "Clients de synchronisation",
     "Everything (fatal issues, errors, warnings, info, debug)" : "Tout (erreurs fatales, erreurs, avertissements, informations, debogage)",
     "Info, warnings, errors and fatal issues" : "Informations, avertissements, erreurs et erreurs fatales",
     "Warnings, errors and fatal issues" : "Avertissements, erreurs et erreurs fatales",
@@ -124,7 +125,6 @@ OC.L10N.register(
     "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP est apparemment configuré pour supprimer les blocs de documentation internes. Cela rendra plusieurs applications de base inaccessibles.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "La raison est probablement l'utilisation d'un cache / accélérateur tel que Zend OPcache ou eAccelerator.",
     "Your server is running on Microsoft Windows. We highly recommend Linux for optimal user experience." : "Votre serveur fonctionne actuellement sur une plateforme Microsoft Windows. Nous vous recommandons fortement d'utiliser une plateforme Linux pour une expérience utilisateur optimale.",
-    "%1$s below version %2$s is installed, for stability and performance reasons we recommend to update to a newer %1$s version." : "Une version de %1$s plus ancienne que %2$s est installée. Pour améliorer la stabilité et les performances, nous recommandons de mettre %1$s à jour.",
     "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "Le module PHP 'fileinfo' est manquant. Il est vivement recommandé de l'activer afin d'obtenir de meilleurs résultats de détection mime-type.",
     "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" href=\"%s\">documentation ↗</a> for more information." : "Le verrouillage transactionnel de fichiers est désactivé. Cela peut causer des conflits en cas d'accès concurrent. Configurez 'filelocking.enabled' dans config.php pour éviter ces problèmes. Consultez la <a target=\"_blank\" href=\"%s\">documentation ↗</a> pour plus d'informations.",
     "System locale can not be set to a one which supports UTF-8." : "Les paramètres régionaux n'ont pu être configurés avec prise en charge d'UTF-8.",
@@ -132,7 +132,6 @@ OC.L10N.register(
     "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Nous vous recommandons d'installer sur votre système les paquets nécessaires à la prise en charge de l'un des paramètres régionaux suivants : %s",
     "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Si votre installation n'a pas été effectuée à la racine du domaine et qu'elle utilise le cron du système, il peut y avoir des problèmes avec la génération d'URL. Pour les éviter, veuillez configurer l'option \"overwrite.cli.url\" de votre fichier config.php avec le chemin de la racine de votre installation (suggéré : \"%s\")",
     "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "La tâche cron n'a pu s'exécuter via CLI. Ces erreurs techniques sont apparues :",
-    "Transactional file locking is using the database as locking backend, for best performance it's advised to configure a memcache for locking. See the <a target=\"_blank\" href=\"%s\">documentation ↗</a> for more information." : "Le verrouillage transactionnel de fichiers utilise la base de données. Pour de meilleures performances il est recommandé d'utiliser plutôt memcache. Consultez la <a target=\"_blank\" href=\"%s\">documentation ↗</a> pour plus d'informations.",
     "Please double check the <a target=\"_blank\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Consultez les <a target=\"_blank\" href=\"%s\">guides d'installation ↗</a>,  et cherchez des erreurs ou avertissements dans  <a href=\"#log-section\">les logs</a>.",
     "All checks passed." : "Tous les tests ont réussi.",
     "Open documentation" : "Voir la documentation",
@@ -159,6 +158,10 @@ OC.L10N.register(
     "Use system's cron service to call the cron.php file every 15 minutes." : "Utilisez le service cron du système pour appeler le fichier cron.php toutes les 15 minutes.",
     "Enable server-side encryption" : "Activer le chiffrement côté serveur",
     "Please read carefully before activating server-side encryption: " : "Veuillez lire ceci avec attention avant d'activer le chiffrement :",
+    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Une fois le chiffrement activé, les fichiers téléversés sur le serveur à partir de ce moment seront stockés sous forme chiffrée. Il n'est possible de désactiver le chiffrement que si le module utilisé le permet spécifiquement, et que toutes les conditions préalables sont réunies pour ce faire (par exemple la création d'une clef de récupération).",
+    "Encryption alone does not guarantee security of the system. Please see ownCloud documentation for more information about how the encryption app works, and the supported use cases." : "Le chiffrement seul ne peut garantir la sécurité du système. Veuillez consulter la documentation ownCloud pour comprendre comment fonctionne l'application de chiffrement, et les cas d'utilisation pris en charge.",
+    "Be aware that encryption always increases the file size." : "Veuillez noter que le chiffrement augmente toujours la taille des fichiers.",
+    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Il est opportun de sauvegarder régulièrement vos données. Si ces données sont chiffrées, n'oubliez pas de sauvegarder aussi les clés de chiffrement.",
     "This is the final warning: Do you really want to enable encryption?" : "Dernier avertissement : Voulez-vous vraiment activer le chiffrement ?",
     "Enable encryption" : "Activer le chiffrement",
     "No encryption module loaded, please enable an encryption module in the app menu." : "Aucun module de chiffrement n'est chargé. Merci d'activer un module de chiffrement dans le menu des applications.",
@@ -181,11 +184,11 @@ OC.L10N.register(
     "Store credentials" : "Enregistrer les identifiants",
     "Test email settings" : "Tester les paramètres e-mail",
     "Send email" : "Envoyer un e-mail",
-    "Log level" : "Niveau de log",
     "Download logfile" : "Télécharger le fichier de journalisation",
     "More" : "Plus",
     "Less" : "Moins",
     "The logfile is bigger than 100 MB. Downloading it may take some time!" : "La taille du fichier journal excède 100 Mo. Le télécharger peut prendre un certain temps!",
+    "What to log" : "Ce qu'il faut journaliser",
     "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "SQLite est actuellement utilisé comme gestionnaire de base de données. Pour des installations plus volumineuses, nous vous conseillons d'utiliser un autre gestionnaire de base de données.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "L'utilisation de SQLite est particulièrement déconseillée si vous utilisez le client de bureau pour synchroniser vos données.",
     "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" href=\"%s\">documentation ↗</a>." : "Pour migrer vers un autre type de base de données, utilisez la ligne de commande : 'occ db:convert-type' ou consultez la <a target=\"_blank\" href=\"%s\">documentation ↗</a>.",
@@ -199,18 +202,26 @@ OC.L10N.register(
     "Developer documentation" : "Documentation pour développeurs",
     "Experimental applications ahead" : "Attention! Applications expérimentales",
     "Experimental apps are not checked for security issues, new or known to be unstable and under heavy development. Installing them can cause data loss or security breaches." : "Les applications expérimentales n'ont pas fait l'objet de tests de sécurité, sont encore en développement et peuvent être instables. Les installer peut causer des pertes de données ou des failles de sécurité. ",
-    "by" : "par",
-    "licensed" : "Sous licence",
+    "by %s" : "par %s",
+    "%s-licensed" : "Sous licence %s",
     "Documentation:" : "Documentation :",
     "User documentation" : "Documentation utilisateur",
     "Admin documentation" : "Documentation administrateur",
     "Show description …" : "Afficher la description...",
     "Hide description …" : "Masquer la description",
+    "This app has an update available." : "Cette application a une mise à jour disponible.",
+    "This app has no minimum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Cette app ne spécifie pas de version d'ownCloud minimale requise. Cela provoquera une erreur dans ownCloud 11+",
+    "This app has no maximum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Cette app ne spécifie pas de version d'ownCloud maximale requise. Cela provoquera une erreur dans ownCloud 11+",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "Cette application ne peut être installée à cause de ces dépendances non satisfaites :",
     "Enable only for specific groups" : "Activer uniquement pour certains groupes",
     "Uninstall App" : "Désinstaller l'application",
     "Enable experimental apps" : "Activer les applications expérimentales",
-    "No apps found for your version" : "Pas d'application trouvée pour votre version",
+    "SSL Root Certificates" : "Certificats Racines SSL",
+    "Common Name" : "Nom d'usage",
+    "Valid until" : "Valide jusqu'à",
+    "Issued By" : "Délivré par",
+    "Valid until %s" : "Valide jusqu'à %s",
+    "Import root certificate" : "Importer un certificat racine",
     "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Bonjour,<br><br>Un compte %s a été créé pour vous.<br><br>Votre nom d'utilisateur est : %s<br>Visitez votre compte : <a href=\"%s\">%s</a><br><br>",
     "Cheers!" : "À bientôt !",
     "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Bonjour,<br><br>Un compte %s a été créé pour vous.<br><br>Votre nom d'utilisateur est : %s<br>Visitez votre compte : %s<br><br>\n",
@@ -219,40 +230,35 @@ OC.L10N.register(
     "Forum" : "Forum",
     "Issue tracker" : "Suivi de problèmes",
     "Commercial support" : "Support commercial",
+    "You are using <strong>%s</strong> of <strong>%s</strong>" : "Vous utilisez <strong>%s</strong> des <strong>%s<strong> disponibles",
+    "Profile picture" : "Photo de profil",
+    "Upload new" : "Nouvelle depuis votre ordinateur",
+    "Select from Files" : "Sélectionner depuis les Fichiers",
+    "Remove image" : "Supprimer l'image",
+    "png or jpg, max. 20 MB" : "png ou jpg, max. 20 Mo",
+    "Picture provided by original account" : "Photo fournie par le compte original",
+    "Cancel" : "Annuler",
+    "Choose as profile picture" : "Définir comme image de profil",
+    "Full name" : "Nom complet",
+    "No display name set" : "Aucun nom d'affichage configuré",
+    "Email" : "Adresse e-mail",
+    "Your email address" : "Votre adresse e-mail",
+    "For password recovery and notifications" : "Pour la récupération de mot de passe et les notifications",
+    "No email address set" : "Aucune adresse e-mail configurée",
+    "You are member of the following groups:" : "Vous êtes membre des groupes suivants :",
+    "Password" : "Mot de passe",
+    "Unable to change your password" : "Impossible de changer votre mot de passe",
+    "Current password" : "Mot de passe actuel",
+    "New password" : "Nouveau mot de passe",
+    "Change password" : "Changer de mot de passe",
+    "Language" : "Langue",
+    "Help translate" : "Aidez à traduire",
     "Get the apps to sync your files" : "Obtenez les applications de synchronisation de vos fichiers",
     "Desktop client" : "Client de bureau",
     "Android app" : "Application Android",
     "iOS app" : "Application iOS",
     "If you want to support the project\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\tor\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "Si vous souhaitez apporter votre support au projet\n        <a href=\"https://owncloud.org/contribute\"\n            target=\"_blank\" rel=\"noreferrer\">rejoignez le développement</a>\n        ou\n        <a href=\"https://owncloud.org/promote\"\n            target=\"_blank\" rel=\"noreferrer\">faites passer le mot</a> !",
     "Show First Run Wizard again" : "Revoir la fenêtre d'accueil affichée lors de votre première connexion",
-    "You have used <strong>%s</strong> of the available <strong>%s</strong>" : "Vous utilisez <strong>%s</strong> des <strong>%s<strong> disponibles",
-    "Password" : "Mot de passe",
-    "Unable to change your password" : "Impossible de changer votre mot de passe",
-    "Current password" : "Mot de passe actuel",
-    "New password" : "Nouveau mot de passe",
-    "Change password" : "Changer de mot de passe",
-    "Full name" : "Nom complet",
-    "No display name set" : "Aucun nom d'affichage configuré",
-    "Email" : "Adresse e-mail",
-    "Your email address" : "Votre adresse e-mail",
-    "Fill in an email address to enable password recovery and receive notifications" : "Saisissez votre adresse e-mail pour permettre la réinitialisation du mot de passe et la réception des notifications",
-    "No email address set" : "Aucune adresse e-mail configurée",
-    "You are member of the following groups:" : "Vous êtes membre des groupes suivants :",
-    "Profile picture" : "Photo de profil",
-    "Upload new" : "Nouvelle depuis votre ordinateur",
-    "Select new from Files" : "Nouvelle depuis les Fichiers",
-    "Remove image" : "Supprimer l'image",
-    "Either png or jpg. Ideally square but you will be able to crop it. The file is not allowed to exceed the maximum size of 20 MB." : "Format png ou jpg de maximum 20 Mo. Idéalement carrée, mais vous pourrez la recadrer.",
-    "Your avatar is provided by your original account." : "Votre avatar est fourni par votre compte original.",
-    "Cancel" : "Annuler",
-    "Choose as profile image" : "Choisir en tant que photo de profil ",
-    "Language" : "Langue",
-    "Help translate" : "Aidez à traduire",
-    "Common Name" : "Nom d'usage",
-    "Valid until" : "Valide jusqu'à",
-    "Issued By" : "Délivré par",
-    "Valid until %s" : "Valide jusqu'à %s",
-    "Import root certificate" : "Importer un certificat racine",
     "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "Développé par la {communityopen}communauté ownCloud{linkclose}, le {githubopen}code source{linkclose} est sous licence {licenseopen}<abbr lang=\"en\" title=\"Affero General Public License\">AGPL</abbr>{linkclose}.",
     "Show storage location" : "Afficher l'emplacement du stockage",
     "Show last log in" : "Montrer la dernière connexion",
