@@ -12,12 +12,10 @@ OC.L10N.register(
     "Log" : "Log",
     "Tips & tricks" : "Suggerimenti e trucchi",
     "Updates" : "Aggiornamenti",
-    "Authentication error" : "Errore di autenticazione",
-    "Your full name has been changed." : "Il tuo nome completo è stato cambiato.",
-    "Unable to change full name" : "Impossibile cambiare il nome completo",
     "Couldn't remove app." : "Impossibile rimuovere l'applicazione.",
     "Language changed" : "Lingua modificata",
     "Invalid request" : "Richiesta non valida",
+    "Authentication error" : "Errore di autenticazione",
     "Admins can't remove themself from the admin group" : "Gli amministratori non possono rimuovere se stessi dal gruppo di amministrazione",
     "Unable to add user to group %s" : "Impossibile aggiungere l'utente al gruppo %s",
     "Unable to remove user from group %s" : "Impossibile rimuovere l'utente dal gruppo %s",
@@ -53,6 +51,8 @@ OC.L10N.register(
     "Invalid user" : "Utente non valido",
     "Unable to change mail address" : "Impossibile cambiare l'indirizzo di posta",
     "Email saved" : "Email salvata",
+    "Your full name has been changed." : "Il tuo nome completo è stato cambiato.",
+    "Unable to change full name" : "Impossibile cambiare il nome completo",
     "Are you really sure you want add \"{domain}\" as trusted domain?" : "Sei sicuro di voler aggiungere \"{domain}\"  come dominio attendibile?",
     "Add trusted domain" : "Aggiungi dominio attendibile",
     "Migration in progress. Please wait until the migration is finished" : "Migrazione in corso. Attendi fino al completamento della migrazione",
@@ -62,10 +62,12 @@ OC.L10N.register(
     "Approved" : "Approvata",
     "Experimental" : "Sperimentale",
     "All" : "Tutti",
+    "No apps found for your version" : "Nessuna applicazione trovata per la tua versione",
     "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "Le applicazioni ufficiali sono sviluppate da e con la comunità di ownCloud. Offrono le funzioni fondamentali di ownCloud e sono pronte per l'utilizzo in produzione.",
     "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Le applicazioni approvate sono sviluppate da sviluppatori affidabili e hanno passato un rapido controllo di sicurezza. Sono attivamente mantenute in un deposito aperto del codice e i loro responsabili le ritengono pronte sia per un utilizzo casuale che per un utilizzo continuativo.",
     "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Questa applicazione non è stata sottoposta a controlli di sicurezza, è nuova o notoriamente instabile. Installala a tuo rischio.",
     "Update to %s" : "Aggiornato a %s",
+    "_You have %n app update pending_::_You have %n app updates pending_" : ["Hai %n aggiornamento di applicazione in corso","Hai %n aggiornamenti di applicazione in corso"],
     "Please wait...." : "Attendere...",
     "Error while disabling app" : "Errore durante la disattivazione",
     "Disable" : "Disabilita",
@@ -79,6 +81,10 @@ OC.L10N.register(
     "Uninstall" : "Disinstalla",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "L'applicazione è stata abilitata, ma deve essere aggiornata. Sarai rediretto alla pagina di aggiornamento in 5 secondi.",
     "App update" : "Aggiornamento applicazione",
+    "No apps found for \"{query}\"" : "Nessuna applicazione trovata per \"{query}\"",
+    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Si è verificato un errore. Carica un certificato PEM codificato in ASCII.",
+    "Valid until {date}" : "Valido fino al {date}",
+    "Delete" : "Elimina",
     "An error occurred: {message}" : "Si è verificato un errore: {message}",
     "Select a profile picture" : "Seleziona un'immagine del profilo",
     "Very weak password" : "Password molto debole",
@@ -86,12 +92,9 @@ OC.L10N.register(
     "So-so password" : "Password così-così",
     "Good password" : "Password buona",
     "Strong password" : "Password forte",
-    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Si è verificato un errore. Carica un certificato PEM codificato in ASCII.",
-    "Valid until {date}" : "Valido fino al {date}",
-    "Delete" : "Elimina",
     "Groups" : "Gruppi",
     "Unable to delete {objName}" : "Impossibile eliminare {objName}",
-    "Error creating group" : "Errore durante la creazione del gruppo",
+    "Error creating group: {message}" : "Errore durante la creazione del gruppo: {message}",
     "A valid group name must be provided" : "Deve essere fornito un nome valido per il gruppo",
     "deleted {groupName}" : "{groupName} eliminato",
     "undo" : "annulla",
@@ -101,13 +104,12 @@ OC.L10N.register(
     "add group" : "aggiungi gruppo",
     "Changing the password will result in data loss, because data recovery is not available for this user" : "Il cambiamento della password causerà una perdita di dati, poiché il ripristino dei dati non è disponibile per questo utente",
     "A valid username must be provided" : "Deve essere fornito un nome utente valido",
-    "Error creating user" : "Errore durante la creazione dell'utente",
+    "Error creating user: {message}" : "Errore durante la creazione dell'utente: {message}",
     "A valid password must be provided" : "Deve essere fornita una password valida",
     "A valid email must be provided" : "Deve essere fornito un indirizzo email valido",
     "__language_name__" : "Italiano",
-    "Sync clients" : "Client di sincronizzazione",
     "Personal info" : "Informazioni personali",
-    "SSL root certificates" : "Certificati SSL radice",
+    "Sync clients" : "Client di sincronizzazione",
     "Everything (fatal issues, errors, warnings, info, debug)" : "Tutto (problemi gravi, errori, avvisi, informazioni, debug)",
     "Info, warnings, errors and fatal issues" : "Informazioni, avvisi, errori e problemi gravi",
     "Warnings, errors and fatal issues" : "Avvisi, errori e problemi gravi",
@@ -125,7 +127,7 @@ OC.L10N.register(
     "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "Sembra che PHP sia configurato per rimuovere i blocchi di documentazione in linea. Ciò renderà inaccessibili diverse applicazioni principali.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Ciò è causato probabilmente da una cache/acceleratore come Zend OPcache o eAccelerator.",
     "Your server is running on Microsoft Windows. We highly recommend Linux for optimal user experience." : "Il tuo server è in esecuzione su Microsoft Windows. Consigliamo vivamente Linux per un'esperienza utente ottimale.",
-    "%1$s below version %2$s is installed, for stability and performance reasons we recommend to update to a newer %1$s version." : "La versione di %1$s installata è anteriore alla %2$s, per motivi di stabilità e prestazioni, consigliamo di aggiornare una una versione di %1$s più recente.",
+    "%1$s below version %2$s is installed, for stability and performance reasons we recommend updating to a newer %1$s version." : "La versione di %1$s installata è anteriore alla %2$s, per motivi di stabilità e prestazioni, consigliamo di aggiornare a una versione di %1$s più recente.",
     "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "Il modulo PHP 'fileinfo' non è presente. Consigliamo vivamente di abilitare questo modulo per ottenere risultati migliori con il rilevamento dei tipi MIME.",
     "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" href=\"%s\">documentation ↗</a> for more information." : "Il blocco del file transazionale è disabilitato, ciò potrebbe comportare problemi di race condition. Abilita 'filelocking.enabled' nel config-php per evitare questi problemi. Vedi la <a target=\"_blank\" href=\"%s\">documentazione ↗</a> per ulteriori informazioni.",
     "System locale can not be set to a one which supports UTF-8." : "La localizzazione di sistema non può essere impostata a una che supporta UTF-8.",
@@ -133,7 +135,6 @@ OC.L10N.register(
     "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Consigliamo vivamente di installare i pacchetti richiesti sul tuo sistema per supportare una delle localizzazioni seguenti: %s.",
     "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Se la tua installazione non si trova nella radice del dominio e utilizza il cron di sistema, potrebbero esserci problemi con la generazione degli URL. Per evitare questi problemi, imposta l'opzione \"overwrite.cli.url\"  nel file config.php al percorso della radice del sito della tua installazione (Consigliato: \"%s\")",
     "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "Non è stato possibile eseguire il job di cron tramite CLI. Sono apparsi i seguenti errori tecnici:",
-    "Transactional file locking is using the database as locking backend, for best performance it's advised to configure a memcache for locking. See the <a target=\"_blank\" href=\"%s\">documentation ↗</a> for more information." : "Il blocco del file transazionale sta utilizzando il database come motore di blocco, per avere prestazioni migliori, è consigliato configurare una cache di memoria per il blocco. Vedi la <a target=\"_blank\" href=\"%s\">documentazione ↗</a> per ulteriori informazioni.",
     "Please double check the <a target=\"_blank\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Leggi attentamente le  <a target=\"_blank\" href=\"%s\">guide d'installazione ↗</a>, e controlla gli errori o gli avvisi nel <a href=\"#log-section\">log</a>.",
     "All checks passed." : "Tutti i controlli passati.",
     "Open documentation" : "Apri la documentazione",
@@ -186,11 +187,11 @@ OC.L10N.register(
     "Store credentials" : "Memorizza le credenziali",
     "Test email settings" : "Prova impostazioni email",
     "Send email" : "Invia email",
-    "Log level" : "Livello di log",
     "Download logfile" : "Scarica file di log",
     "More" : "Altro",
     "Less" : "Meno",
     "The logfile is bigger than 100 MB. Downloading it may take some time!" : "Il file di log è più grande di 100MB. Scaricarlo potrebbe richiedere del tempo!",
+    "What to log" : "Cosa registrare",
     "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "SQLite è utilizzato come database. Per installazioni più grandi consigliamo di passare a un motore di database diverso.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "In particolar modo, quando si utilizza il client desktop per la sincronizzazione dei file, l'uso di SQLite è sconsigliato.",
     "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" href=\"%s\">documentation ↗</a>." : "Per migrare a un altro database, usa lo strumento da riga di comando: 'occ db:convert-type', o leggi la <a target=\"_blank\" href=\"%s\">documentazione ↗</a>.",
@@ -204,18 +205,26 @@ OC.L10N.register(
     "Developer documentation" : "Documentazione dello sviluppatore",
     "Experimental applications ahead" : "Prima le applicazioni sperimentali",
     "Experimental apps are not checked for security issues, new or known to be unstable and under heavy development. Installing them can cause data loss or security breaches." : "Le applicazioni sperimentali non sono sottoposte a controlli di sicurezza, sono nuove o notoriamente instabili e sotto sviluppo intensivo. La loro installazione può causare perdite di dati o problemi di sicurezza.",
-    "by" : "di",
-    "licensed" : "sotto licenza",
+    "by %s" : "di %s",
+    "%s-licensed" : "sotto licenza %s",
     "Documentation:" : "Documentazione:",
     "User documentation" : "Documentazione utente",
     "Admin documentation" : "Documentazione di amministrazione",
     "Show description …" : "Mostra descrizione...",
     "Hide description …" : "Nascondi descrizione...",
+    "This app has an update available." : "Un aggiornamento di questa applicazione è disponibile.",
+    "This app has no minimum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Questa applicazione non ha una versione minima di ownCloud assegnata. Ciò costituirà un errore in ownCloud 11 e successive.",
+    "This app has no maximum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Questa applicazione non ha una versione massima di ownCloud assegnata. Ciò costituirà un errore in ownCloud 11 e successive.",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "Questa applicazione non può essere installata perché le seguenti dipendenze non sono soddisfatte:",
     "Enable only for specific groups" : "Abilita solo per gruppi specifici",
     "Uninstall App" : "Disinstalla applicazione",
     "Enable experimental apps" : "Abilita le applicazioni sperimentali",
-    "No apps found for your version" : "Nessuna applicazione trovata per la tua versione",
+    "SSL Root Certificates" : "Certificati radice SSL",
+    "Common Name" : "Nome comune",
+    "Valid until" : "Valido fino al",
+    "Issued By" : "Emesso da",
+    "Valid until %s" : "Valido fino al %s",
+    "Import root certificate" : "Importa certificato radice",
     "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Ciao,<br><br>volevo informarti che ora hai un account %s.<br><br>Il tuo nome utente: %s<br>Accedi: <a href=\"%s\">%s</a><br><br>",
     "Cheers!" : "Saluti!",
     "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Ciao,\n\nvolevo informarti che ora hai un account %s.\n\nIl tuo nome utente: %s\nAccedi: %s\n\n",
@@ -224,40 +233,35 @@ OC.L10N.register(
     "Forum" : "Forum",
     "Issue tracker" : "Sistema di tracciamento dei problemi",
     "Commercial support" : "Supporto commerciale",
+    "You are using <strong>%s</strong> of <strong>%s</strong>" : "Stai utilizzando <strong>%s</strong> di <strong>%s</strong>",
+    "Profile picture" : "Immagine del profilo",
+    "Upload new" : "Carica nuova",
+    "Select from Files" : "Seleziona da file",
+    "Remove image" : "Rimuovi immagine",
+    "png or jpg, max. 20 MB" : "png o jpg, max. 20 MB",
+    "Picture provided by original account" : "Immagine fornita dall'account originale",
+    "Cancel" : "Annulla",
+    "Choose as profile picture" : "Scegli come immagine del profilo",
+    "Full name" : "Nome completo",
+    "No display name set" : "Nome visualizzato non impostato",
+    "Email" : "Posta elettronica",
+    "Your email address" : "Il tuo indirizzo email",
+    "For password recovery and notifications" : "Per il ripristino della password e per le notifiche",
+    "No email address set" : "Nessun indirizzo email impostato",
+    "You are member of the following groups:" : "Sei membro dei seguenti gruppi:",
+    "Password" : "Password",
+    "Unable to change your password" : "Modifica password non riuscita",
+    "Current password" : "Password attuale",
+    "New password" : "Nuova password",
+    "Change password" : "Modifica password",
+    "Language" : "Lingua",
+    "Help translate" : "Migliora la traduzione",
     "Get the apps to sync your files" : "Scarica le applicazioni per sincronizzare i tuoi file",
     "Desktop client" : "Client desktop",
     "Android app" : "Applicazione Android",
     "iOS app" : "Applicazione iOS",
     "If you want to support the project\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\tor\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "Se vuoi supportare il progetto\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">diventa uno sviluppatore</a>\n\t\to\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">diffondi il verbo</a>!",
     "Show First Run Wizard again" : "Mostra nuovamente la procedura di primo avvio",
-    "You have used <strong>%s</strong> of the available <strong>%s</strong>" : "Hai utilizzato <strong>%s</strong> dei <strong>%s</strong> disponibili",
-    "Password" : "Password",
-    "Unable to change your password" : "Modifica password non riuscita",
-    "Current password" : "Password attuale",
-    "New password" : "Nuova password",
-    "Change password" : "Modifica password",
-    "Full name" : "Nome completo",
-    "No display name set" : "Nome visualizzato non impostato",
-    "Email" : "Posta elettronica",
-    "Your email address" : "Il tuo indirizzo email",
-    "Fill in an email address to enable password recovery and receive notifications" : "Inserisci il tuo indirizzo di posta per abilitare il ripristino della password e ricevere notifiche",
-    "No email address set" : "Nessun indirizzo email impostato",
-    "You are member of the following groups:" : "Sei membro dei seguenti gruppi:",
-    "Profile picture" : "Immagine del profilo",
-    "Upload new" : "Carica nuova",
-    "Select new from Files" : "Seleziona nuova da file",
-    "Remove image" : "Rimuovi immagine",
-    "Either png or jpg. Ideally square but you will be able to crop it. The file is not allowed to exceed the maximum size of 20 MB." : "Sia png che jpg. Preferibilmente quadrata, ma potrai ritagliarla. Il file non può superare la dimensione massima di 20 MB.",
-    "Your avatar is provided by your original account." : "Il tuo avatar è ottenuto dal tuo account originale.",
-    "Cancel" : "Annulla",
-    "Choose as profile image" : "Scegli come immagine del profilo",
-    "Language" : "Lingua",
-    "Help translate" : "Migliora la traduzione",
-    "Common Name" : "Nome comune",
-    "Valid until" : "Valido fino al",
-    "Issued By" : "Emesso da",
-    "Valid until %s" : "Valido fino al %s",
-    "Import root certificate" : "Importa certificato radice",
     "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "Sviluppato dalla {communityopen}comunità di ownCloud{linkclose}, il {githubopen}codice sorgente{linkclose} è rilasciato nei termini della licenza {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}.",
     "Show storage location" : "Mostra posizione di archiviazione",
     "Show last log in" : "Mostra ultimo accesso",
