@@ -5,18 +5,17 @@ OC.L10N.register(
     "Redis" : "Redis",
     "Security & setup warnings" : "Avisos de configuração e segurança",
     "Sharing" : "Partilha",
+    "Server-side encryption" : "Atualizar App",
     "External Storage" : "Armazenamento Externo",
     "Cron" : "Cron",
     "Email server" : "Servidor de Correio Eletrónico",
     "Log" : "Registo",
     "Tips & tricks" : "Dicas e truqes",
     "Updates" : "Atualizações",
-    "Authentication error" : "Erro na autenticação",
-    "Your full name has been changed." : "O seu nome completo foi alterado.",
-    "Unable to change full name" : "Não foi possível alterar o seu nome completo",
     "Couldn't remove app." : "Não foi possível remover a aplicação.",
     "Language changed" : "Idioma alterado",
     "Invalid request" : "Pedido Inválido",
+    "Authentication error" : "Erro na autenticação",
     "Admins can't remove themself from the admin group" : "Os administradores não se podem remover a eles próprios do grupo 'admin'.",
     "Unable to add user to group %s" : "Não é possível adicionar o utilizador ao grupo %s",
     "Unable to remove user from group %s" : "Não é possível remover o utilizador do grupo %s",
@@ -29,7 +28,9 @@ OC.L10N.register(
     "Unable to change password" : "Não foi possível alterar a sua palavra-passe ",
     "Enabled" : "Ativada",
     "Not enabled" : "Desativada",
+    "installing and updating apps via the app store or Federated Cloud Sharing" : "instalando e atualizando aplicações via loja de aplicações ou Partilha de Nuvem Federada",
     "Federated Cloud Sharing" : "Partilha de Cloud Federada",
+    "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cURL está a usar uma versão %s desatualizada (%s). Por favor, atualize o seu sistema operativo ou algumas funcionalidades como %s não funcionarão corretamente.",
     "A problem occurred, please check your log files (Error: %s)" : "Ocorreu um problema, por favor, verifique os ficheiros de registo (Erro: %s)",
     "Migration Completed" : "Migração Concluída",
     "Group already exists." : "O grupo já existe.",
@@ -50,6 +51,8 @@ OC.L10N.register(
     "Invalid user" : "Utilizador inválido",
     "Unable to change mail address" : "Não foi possível alterar o teu endereço de email",
     "Email saved" : "E-mail guardado",
+    "Your full name has been changed." : "O seu nome completo foi alterado.",
+    "Unable to change full name" : "Não foi possível alterar o seu nome completo",
     "Are you really sure you want add \"{domain}\" as trusted domain?" : "Você tem certeza que quer adicionar \"{domain}\" como domínio confiável?",
     "Add trusted domain" : "Adicionar domínio confiável ",
     "Migration in progress. Please wait until the migration is finished" : "Migração em progresso. Por favor, aguarde até que a mesma esteja concluída..",
@@ -59,8 +62,12 @@ OC.L10N.register(
     "Approved" : "Aprovado",
     "Experimental" : "Experimental",
     "All" : "Todos",
+    "No apps found for your version" : "Nenhuma aplicação encontrada para a sua versão",
     "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "As apps oficiais são desenvolvidas por e na comunidade da ownCloud. Elas oferecem funcionalidade central para a ownCloud e está pronta para uma utilização na produção.",
+    "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "As aplicações aprovadas são desenvolvidas por developers de confiança e passaram numa verificação de segurança. São mantidas ativamente num repositório de código aberto e quem as mantém considera-as estáveis para uso casual a normal.",
+    "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Esta aplicação não foi verificada por problemas de segurança e é nova ou conhecida por ser instável. Instale-a por sua conta e risco.",
     "Update to %s" : "Actualizar para %s",
+    "_You have %n app update pending_::_You have %n app updates pending_" : ["Você tem %n atualização de aplicação pendente","Você tem %n atualizações de aplicações pendentes"],
     "Please wait...." : "Por favor, aguarde...",
     "Error while disabling app" : "Ocorreu  um erro enquanto desativava a app",
     "Disable" : "Desativar",
@@ -72,6 +79,12 @@ OC.L10N.register(
     "Uninstalling ...." : "A desinstalar....",
     "Error while uninstalling app" : "Ocorreu um erro durante a desinstalação da app",
     "Uninstall" : "Desinstalar",
+    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "A aplicação foi ativada, mas precisa de ser atualizada. Você será redirecionado para a página de atualização em 5 segundos.",
+    "App update" : "Atualizar App",
+    "No apps found for \"{query}\"" : "Não foram encontradas aplicações para \"{query}\"",
+    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Ocorreu um erro. Por favor, envie um certificado PEM codificado em ASCII.",
+    "Valid until {date}" : "Válida até {date}",
+    "Delete" : "Apagar",
     "An error occurred: {message}" : "Ocorreu um erro: {message}",
     "Select a profile picture" : "Selecione uma fotografia de perfil",
     "Very weak password" : "Palavra-passe muito fraca",
@@ -79,11 +92,9 @@ OC.L10N.register(
     "So-so password" : "Palavra-passe aceitável",
     "Good password" : "Palavra-passe boa",
     "Strong password" : "Palavra-passe forte",
-    "Valid until {date}" : "Válida até {date}",
-    "Delete" : "Apagar",
     "Groups" : "Grupos",
     "Unable to delete {objName}" : "Não é possível apagar {objNome}",
-    "Error creating group" : "Ocorreu um erro ao criar o grupo",
+    "Error creating group: {message}" : "Erro ao criar grupo: {message}",
     "A valid group name must be provided" : "Deve ser indicado um nome de grupo válido",
     "deleted {groupName}" : "{groupName} apagado",
     "undo" : "Anular",
@@ -93,13 +104,12 @@ OC.L10N.register(
     "add group" : "Adicionar grupo",
     "Changing the password will result in data loss, because data recovery is not available for this user" : "A alteração da palavra-passe resultará na perda de dados, porque a recuperação de dados não está disponível para este utilizador",
     "A valid username must be provided" : "Deve ser indicado um nome de utilizador válido",
-    "Error creating user" : "Ocorreu um erro ao criar o utilizador",
+    "Error creating user: {message}" : "Erro ao criar utilizador: {message}",
     "A valid password must be provided" : "Deve ser indicada uma palavra-passe válida",
     "A valid email must be provided" : "Deve ser fornecido um email válido",
     "__language_name__" : "__language_name__",
-    "Sync clients" : "Clientes de sync",
     "Personal info" : "Informação pessoal",
-    "SSL root certificates" : "Certificados de raiz SSL",
+    "Sync clients" : "Clientes de sync",
     "Everything (fatal issues, errors, warnings, info, debug)" : "Tudo (problemas fatais, erros, avisos, informação, depuração)",
     "Info, warnings, errors and fatal issues" : "Informação, avisos, erros e problemas fatais",
     "Warnings, errors and fatal issues" : "Avisos, erros e problemas fatais",
@@ -111,17 +121,22 @@ OC.L10N.register(
     "NT LAN Manager" : "Gestor de REDE NT",
     "SSL" : "SSL",
     "TLS" : "TLS",
+    "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "php não parece estar bem instalado para consultar variáveis de ambiente do sistema. O teste com getenv(\"PATH\") apenas devolveu uma resposta em branco.",
+    "Please check the <a target=\"_blank\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Por favor, verifique a <a target=\"_blank\" href=\"%s\">documentação de instalação ↗</a> para notas de configuração do php e configuração php do seu servidor, especialmente quando utiliza php-fpm.",
     "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "A configuração Só-de-Leitura foi ativada. Isto evita definir algumas configurações através da interface da Web. Além disso, o ficheiro precisa de ser definido gravável manualmente para cada atualização.",
     "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP está aparentemente configurado a remover blocos doc em linha. Isto vai fazer algumas aplicações basicas inacessíveis.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Isto é provavelmente causado por uma cache/acelerador como o Zend OPcache or eAcelerador.",
     "Your server is running on Microsoft Windows. We highly recommend Linux for optimal user experience." : "O seu servidor está a correr Microsoft Windows. Nós recomendamos Linux para uma experiência de utilizador optimizada.",
+    "%1$s below version %2$s is installed, for stability and performance reasons we recommend updating to a newer %1$s version." : "%1$s abaixo da versão %2$s está instalado. Por motivos de estabilidade e desempenho, recomendamos que atualize para a nova versão %1$s.",
     "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "O Módulo PHP 'fileinfo' não se encontra instalado/activado. É fortemente recomendado que active este módulo para obter os melhores resultado com a detecção dos tipos de mime.",
+    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" href=\"%s\">documentation ↗</a> for more information." : "Bloqueio de arquivos transacionais está desativado, isto poderá levar a problemas com condições de corrida. Ative 'filelocking.enabled' no config.php para evitar estes problemas. Consulte a <a target=\"_blank\" href=\"%s\">documentação ↗</a> para mais informação.",
     "System locale can not be set to a one which supports UTF-8." : "Não é possível definir a internacionalização do sistema para um que suporte o UTF-8.",
     "This means that there might be problems with certain characters in file names." : "Isto significa que podem haver problemas com alguns caracteres nos nomes dos ficheiros.",
     "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Nós recomendamos fortemente que instale no seu sistema os pacotes necessários para suportar uma das seguintes locallidades: %s.",
     "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Se a sua instalação não está instalada na raiz do domínio e usa o sistema cron, pode haver problemas com a geração de URL. Para evitar esses problemas, por favor, defina a opção \"overwrite.cli.url\" no ficheiro config.php para o caminho webroot da sua instalação (Sugestão: \"%s\")",
     "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "Não foi possível executar o cronjob via CLI. Os seguintes erros técnicos apareceram:",
     "Please double check the <a target=\"_blank\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Por favor, verifique os <a target=\"_blank\" href=\"%s\">guias de instalação ↗</a>, e verifique se existe algum erro ou aviso no <a href=\"#log-section\">log</a>.",
+    "All checks passed." : "Todas as verificações passaram.",
     "Open documentation" : "Abrir documentação",
     "Allow apps to use the Share API" : "Permitir que os utilizadores usem a API de partilha",
     "Allow users to share via link" : "Permitir que os utilizadores partilhem através do link",
@@ -137,13 +152,25 @@ OC.L10N.register(
     "Allow users to send mail notification for shared files to other users" : "Autorizar utilizadores a enviarem notificações de email acerca de ficheiros partilhados a outros utilizadores",
     "Exclude groups from sharing" : "Excluir grupos das partilhas",
     "These groups will still be able to receive shares, but not to initiate them." : "Estes grupos poderão receber partilhas, mas não poderão iniciá-las.",
+    "Allow username autocompletion in share dialog. If this is disabled the full username needs to be entered." : "Permitir o auto-completar de nome de utilizador no diálogo da partilha. Se isto for desativado, será necessário preencher o nome de utilizador completo.",
     "Last cron job execution: %s." : "Última execução de cron job: %s.",
     "Last cron job execution: %s. Something seems wrong." : "Última execução de cron job: %s. Algo está errado.",
     "Cron was not executed yet!" : "Cron ainda não foi executado!",
     "Execute one task with each page loaded" : "Executar uma tarefa com cada página carregada",
     "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php está registado num serviço webcron para chamar a página cron.php por http a cada 15 minutos.",
     "Use system's cron service to call the cron.php file every 15 minutes." : "Usar o serviço sistema cron para ligar o ficheiro cron.php a cada 15 minutos.",
+    "Enable server-side encryption" : "Ativar encriptação do lado do servidor",
+    "Please read carefully before activating server-side encryption: " : "Por favor, leia cuidadosamente antes de ativar a encriptação do lado do servidor:",
+    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Uma vez ativada a encriptação, todos os ficheiros carregados para o servidor a partir deste ponto serão encriptados pelo servidor. Só será possível desativar a encriptação numa data mais tarde se o módulo de encriptação ativo suportar essa função, assim como todas as pré-condições (e.g. definir chave de recuperação) sejam cumpridas.",
+    "Encryption alone does not guarantee security of the system. Please see ownCloud documentation for more information about how the encryption app works, and the supported use cases." : "A encriptação por si só não garante a segurança do sistema. Por favor, consulte a documentação ownCloud para mais informação acerca de como funciona a aplicação de encriptação, assim como os casos de uso suportados.",
+    "Be aware that encryption always increases the file size." : "Tenha em conta que a encriptação aumenta sempre o tamanho do ficheiro.",
+    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "É sempre bom criar cópias de segurança regulares dos seus dados, em caso de encriptação tenha a certeza de que faz cópia das chaves de encriptação em conjunto com os seus dados.",
+    "This is the final warning: Do you really want to enable encryption?" : "Este é o aviso final: quer mesmo ativar a encriptação?",
     "Enable encryption" : "Ative a encriptação",
+    "No encryption module loaded, please enable an encryption module in the app menu." : "Nenhum módulo de encriptação carregador, por favor ative um módulo de encriptação no menu das aplicações.",
+    "Select default encryption module:" : "Selecionar o módulo de encriptação predefinido:",
+    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Precisa de migrar as suas chaves de encriptação da encriptação antiga (ownCloud <= 8.0) para a nova. Por favor, ative o \"Módulo de encriptação padrão\" e execute 'occ encryption:migrate'",
+    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Precisa de migrar as suas chaves de encriptação da encriptação antiga (ownCloud <= 8.0) para a nova.",
     "Start migration" : "Iniciar migração",
     "This is used for sending out notifications." : "Isto é utilizado para enviar notificações",
     "Send mode" : "Modo de Envio",
@@ -160,11 +187,11 @@ OC.L10N.register(
     "Store credentials" : "Armazenar credenciais",
     "Test email settings" : "Testar definições de e-mail",
     "Send email" : "Enviar email",
-    "Log level" : "Nível do registo",
     "Download logfile" : "Descarregar logfile",
     "More" : "Mais",
     "Less" : "Menos",
     "The logfile is bigger than 100 MB. Downloading it may take some time!" : "O logfile é maior que 100MB. O download do mesmo poderá demorar algum tempo!",
+    "What to log" : "Fazer log do quê?",
     "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "SQLite é utilizado como uma base de dados. Para instalações maiores nós recomendamos que mude para uma interface de base de dados diferente.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "O uso de SQLite é desencorajado especialmente se estiver a pensar em dar uso ao cliente desktop para sincronizar os seus ficheiros no seu computador.",
     "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" href=\"%s\">documentation ↗</a>." : "Para migrar para outro tipo de base de dados, use a ferramenta de comando de linha: 'occ db:convert-type', ou seja a <a target=\"_blank\" href=\"%s\">documentação↗</a>.",
@@ -178,18 +205,26 @@ OC.L10N.register(
     "Developer documentation" : "Documentação de Programador",
     "Experimental applications ahead" : "Aplicações experimentais de futuro",
     "Experimental apps are not checked for security issues, new or known to be unstable and under heavy development. Installing them can cause data loss or security breaches." : "As apps experimentais não estão selecionadas para problemas de segurança, nova ou conhecida como instável e em forte desenvolvimento. Ao instalá-las pode causar a perda de dados ou quebra de segurança.",
-    "by" : "por",
-    "licensed" : "licenciado",
+    "by %s" : "por %s",
+    "%s-licensed" : "%s-autorizado",
     "Documentation:" : "Documentação:",
     "User documentation" : "Documentação de Utilizador",
     "Admin documentation" : "Documentação do Administrador",
     "Show description …" : "Mostrar descrição ...",
     "Hide description …" : "Esconder descrição ...",
+    "This app has an update available." : "Esta aplicação tem uma atualização disponível.",
+    "This app has no minimum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Esta aplicação não tem uma versão mínima de ownCloud atribuída. Isto será um erro no ownCloud 11 e seguintes.",
+    "This app has no maximum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Esta aplicação não tem uma versão máxima de ownCloud atribuída. Isto será um erro no ownCloud 11 e seguintes.",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "Esta aplicação não pode ser instalada porque as seguintes dependências não podem ser realizadas:",
     "Enable only for specific groups" : "Activar só para grupos específicos",
     "Uninstall App" : "Desinstalar aplicação",
     "Enable experimental apps" : "Ativar apps experimentais",
-    "No apps found for your version" : "Nenhuma aplicação encontrada para a sua versão",
+    "SSL Root Certificates" : "Certificados SSL Root",
+    "Common Name" : "Nome Comum",
+    "Valid until" : "Válido até",
+    "Issued By" : "Emitido Por",
+    "Valid until %s" : "Válido até %s",
+    "Import root certificate" : "Importar certificado root",
     "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Olá,<br><br>apenas para informar que você tem uma conta %s.<br><br>O seu nome de utilizador: %s<br>Acesse à sua conta: <a href=\"%s\">%s</a><br><br>",
     "Cheers!" : "Parabéns!",
     "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Olá,\n\napenas para informar que você tem uma conta %s.\n\nO seu nome de utilizador: %s\nAcesse à sua conta: %s\n\n",
@@ -198,39 +233,35 @@ OC.L10N.register(
     "Forum" : "Fórum",
     "Issue tracker" : "Pesquisador de problemad",
     "Commercial support" : "Suporte Comercial",
+    "You are using <strong>%s</strong> of <strong>%s</strong>" : "Está a usar <strong>%s</strong> de <strong>%s</strong>",
+    "Profile picture" : "Foto do perfil",
+    "Upload new" : "Carregar novo",
+    "Select from Files" : "Seleccione dos Ficheiros",
+    "Remove image" : "Remover imagem",
+    "png or jpg, max. 20 MB" : "png ou jpg, máx. 20 MB",
+    "Picture provided by original account" : "Imagem fornecida pela conta original",
+    "Cancel" : "Cancelar",
+    "Choose as profile picture" : "Escolher como fotografia de perfil",
+    "Full name" : "Nome completo",
+    "No display name set" : "Nenhum nome display estabelecido",
+    "Email" : "Email",
+    "Your email address" : "O seu endereço de email",
+    "For password recovery and notifications" : "Para recuperação da palavra-passe e notificações",
+    "No email address set" : "Nenhum endereço de email estabelecido",
+    "You are member of the following groups:" : "Você é membro dos seguintes grupos:",
+    "Password" : "Palavra-passe",
+    "Unable to change your password" : "Não foi possível alterar a sua palavra-passe",
+    "Current password" : "Palavra-passe atual",
+    "New password" : "Nova palavra-passe",
+    "Change password" : "Alterar palavra-passe",
+    "Language" : "Idioma",
+    "Help translate" : "Ajude a traduzir",
     "Get the apps to sync your files" : "Obtenha as aplicações para sincronizar os seus ficheiros",
     "Desktop client" : "Cliente Desktop",
     "Android app" : "Aplicação Android",
     "iOS app" : "Aplicação iOS",
     "If you want to support the project\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\tor\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "Se quer apoiar o projecto\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">junte-se ao desenvolvimento</a>\n\t\tou\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">espalhe a palavra</a>!",
     "Show First Run Wizard again" : "Mostrar novamente Wizard de Arranque Inicial",
-    "You have used <strong>%s</strong> of the available <strong>%s</strong>" : "Usou <strong>%s</strong> do disponivel <strong>%s</strong>",
-    "Password" : "Palavra-passe",
-    "Unable to change your password" : "Não foi possível alterar a sua palavra-passe",
-    "Current password" : "Palavra-passe atual",
-    "New password" : "Nova palavra-passe",
-    "Change password" : "Alterar palavra-passe",
-    "Full name" : "Nome completo",
-    "No display name set" : "Nenhum nome display estabelecido",
-    "Email" : "Email",
-    "Your email address" : "O seu endereço de email",
-    "Fill in an email address to enable password recovery and receive notifications" : "Preencha com um endereço e-mail para permitir a recuperação da palavra-passe e receber notificações",
-    "No email address set" : "Nenhum endereço de email estabelecido",
-    "You are member of the following groups:" : "Você é membro dos seguintes grupos:",
-    "Profile picture" : "Foto do perfil",
-    "Upload new" : "Carregar novo",
-    "Select new from Files" : "Seleccionar novo a partir dos ficheiros",
-    "Remove image" : "Remover imagem",
-    "Your avatar is provided by your original account." : "O seu avatar é fornecido pela sua conta original.",
-    "Cancel" : "Cancelar",
-    "Choose as profile image" : "Escolha uma fotografia de perfil",
-    "Language" : "Idioma",
-    "Help translate" : "Ajude a traduzir",
-    "Common Name" : "Nome Comum",
-    "Valid until" : "Válido até",
-    "Issued By" : "Emitido Por",
-    "Valid until %s" : "Válido até %s",
-    "Import root certificate" : "Importar certificado root",
     "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "Desenvolvido pela {communityopen}comunidade ownCloud{linkclose}, o {githubopen}código-fonte{linkclose} está licenciado sob a {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}.",
     "Show storage location" : "Mostrar a localização do armazenamento",
     "Show last log in" : "Mostrar ultimo acesso de entrada",
