@@ -12,12 +12,10 @@ OC.L10N.register(
     "Log" : "Dnevnik",
     "Tips & tricks" : "Nasveti in triki",
     "Updates" : "Posodobitve",
-    "Authentication error" : "Napaka med overjanjem",
-    "Your full name has been changed." : "Vaše polno ime je spremenjeno.",
-    "Unable to change full name" : "Ni mogoče spremeniti polnega imena",
     "Couldn't remove app." : "Ni mogoče odstraniti programa.",
     "Language changed" : "Jezik je spremenjen",
     "Invalid request" : "Neveljavna zahteva",
+    "Authentication error" : "Napaka med overjanjem",
     "Admins can't remove themself from the admin group" : "Skrbnikov ni mogoče odstraniti iz skupine skrbnikov (admin)",
     "Unable to add user to group %s" : "Uporabnika ni mogoče dodati k skupini %s",
     "Unable to remove user from group %s" : "Uporabnika ni mogoče odstraniti iz skupine %s",
@@ -29,20 +27,20 @@ OC.L10N.register(
     "Unable to change password" : "Ni mogoče spremeniti gesla",
     "Enabled" : "Omogočeno",
     "Not enabled" : "Ni omogočeno",
-    "Federated Cloud Sharing" : "Upravljana souporaba oblaka",
-    "A problem occurred, please check your log files (Error: %s)" : "Pojavila se je težava. Prosimo, preverite dnevniške zapise (Napaka: %s)",
-    "Migration Completed" : "Selitev zaključena",
+    "Federated Cloud Sharing" : "Souporaba s prenosom dovoljenj",
+    "A problem occurred, please check your log files (Error: %s)" : "Prišlo je do napake. Preverite dnevniške zapise (napaka: %s).",
+    "Migration Completed" : "Selitev je končana",
     "Group already exists." : "Skupina že obstaja.",
     "Unable to add group." : "Ni mogoče dodati skupine",
     "Unable to delete group." : "Ni mogoče izbrisati skupine.",
-    "log-level out of allowed range" : "stopnja zapisovanja izven območja",
+    "log-level out of allowed range" : "stopnja zapisovanja je izven dovoljenega območja",
     "Saved" : "Shranjeno",
     "test email settings" : "preizkusi nastavitve elektronske pošte",
-    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Med pošiljanjem sporočila se je pojavila težava. Preglejte nastavitve. (Napaka: %s)",
+    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Med pošiljanjem sporočila se je prišlo do napake. Preverite nastavitve (napaka: %s).",
     "Email sent" : "Elektronska pošta je poslana",
     "You need to set your user email before being able to send test emails." : "Pred preizkusnim pošiljanjem sporočil je treba nastaviti elektronski naslov uporabnika.",
     "Invalid mail address" : "Neveljaven elektronski naslov",
-    "A user with that name already exists." : "Uporabnik s takim imenom že obstaja.",
+    "A user with that name already exists." : "Uporabnik s tem imenom že obstaja.",
     "Unable to create user." : "Ni mogoče ustvariti uporabnika.",
     "Your %s account was created" : "Račun %s je uspešno ustvarjen.",
     "Unable to delete user." : "Ni mogoče izbrisati uporabnika",
@@ -50,16 +48,20 @@ OC.L10N.register(
     "Invalid user" : "Neveljavni podatki uporabnika",
     "Unable to change mail address" : "Ni mogoče spremeniti naslova elektronske pošte.",
     "Email saved" : "Elektronski naslov je shranjen",
+    "Your full name has been changed." : "Vaše polno ime je spremenjeno.",
+    "Unable to change full name" : "Ni mogoče spremeniti polnega imena",
     "Are you really sure you want add \"{domain}\" as trusted domain?" : "Ali ste prepričani, da želite dodati \"{domain}\" kot varno domeno?",
     "Add trusted domain" : "Dodaj varno domeno",
-    "Migration in progress. Please wait until the migration is finished" : "Selitev v teku. Prosimo, počakajte, da se selitev zaključi.",
-    "Migration started …" : "Selitev pognana...",
+    "Migration in progress. Please wait until the migration is finished" : "V teku je selitev. Počakajte, da se zaključi.",
+    "Migration started …" : "Selitev je začeta ...",
     "Sending..." : "Poteka pošiljanje ...",
     "Official" : "Uradno",
     "Approved" : "Odobreno",
     "Experimental" : "Preizkusno",
     "All" : "Vsi",
+    "No apps found for your version" : "Ni aplikacij za vašo verzijo",
     "Update to %s" : "Posodobi na %s",
+    "_You have %n app update pending_::_You have %n app updates pending_" : ["Na čakanju je %n posodobitev","Na čakanju sta %n posodobitvi","Na čakanju so %n posodobitve","Na čakanju je %n posodobitev"],
     "Please wait...." : "Počakajte ...",
     "Error while disabling app" : "Napaka onemogočanja programa",
     "Disable" : "Onemogoči",
@@ -71,17 +73,22 @@ OC.L10N.register(
     "Uninstalling ...." : "Odstranjevanje namestitve ...",
     "Error while uninstalling app" : "Prišlo je do napake med odstranjevanjem programa.",
     "Uninstall" : "Odstrani namestitev",
+    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Aplikacija je bila vključena in zahteva še posodobitev. Preusmerjeni boste na stran za posodobitev v 5 sekundah.",
+    "App update" : "Posodabljanje aplikacije",
+    "No apps found for \"{query}\"" : "Ne najdem aplikacije za \"{query}\"",
+    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Prišlo je do napake. Uvoziti je treba ustrezno ASCII kodirano potrdilo PEM.",
+    "Valid until {date}" : "Veljavno do {date}",
+    "Delete" : "Izbriši",
+    "An error occurred: {message}" : "Prišlo je do napake: {message}",
     "Select a profile picture" : "Izbor slike profila",
     "Very weak password" : "Zelo šibko geslo",
     "Weak password" : "Šibko geslo",
     "So-so password" : "Slabo geslo",
     "Good password" : "Dobro geslo",
     "Strong password" : "Odlično geslo",
-    "Valid until {date}" : "Veljavno do {date}",
-    "Delete" : "Izbriši",
     "Groups" : "Skupine",
     "Unable to delete {objName}" : "Ni mogoče izbrisati {objName}",
-    "Error creating group" : "Napaka ustvarjanja skupine",
+    "Error creating group: {message}" : "Napaka ustvarjanja skupine: {message}",
     "A valid group name must be provided" : "Navedeno mora biti veljavno ime skupine",
     "deleted {groupName}" : "izbrisano {groupName}",
     "undo" : "razveljavi",
@@ -91,13 +98,12 @@ OC.L10N.register(
     "add group" : "dodaj skupino",
     "Changing the password will result in data loss, because data recovery is not available for this user" : "Sprememba gesla bo povzročila izgubo podatkov, ker obnova podatkov za tega uporabnika ni na voljo.",
     "A valid username must be provided" : "Navedeno mora biti veljavno uporabniško ime",
-    "Error creating user" : "Napaka ustvarjanja uporabnika",
+    "Error creating user: {message}" : "Napaka ustvarjanja uporabnika: {message}",
     "A valid password must be provided" : "Navedeno mora biti veljavno geslo",
     "A valid email must be provided" : "Naveden mora biti veljaven naslov elektronske pošte.",
     "__language_name__" : "Slovenščina",
-    "Sync clients" : "Uskladi odjemalce",
     "Personal info" : "Osebni podatki",
-    "SSL root certificates" : "Korenska potrdila SSL",
+    "Sync clients" : "Uskladi odjemalce",
     "Everything (fatal issues, errors, warnings, info, debug)" : "Vse (podrobnosti, opozorila, hrošče, napake in usodne dogodke)",
     "Info, warnings, errors and fatal issues" : "Podrobnosti, opozorila, napake in usodne dogodke",
     "Warnings, errors and fatal issues" : "Opozorila, napake in usodne dogodke",
@@ -113,6 +119,7 @@ OC.L10N.register(
     "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "Manjka modul PHP 'fileinfo'. Priporočljivo je omogočiti ta modul za popolno zaznavanje vrst MIME.",
     "System locale can not be set to a one which supports UTF-8." : "Sistemskih jezikovnih nastavitev ni mogoče nastaviti na možnost, ki podpira nabor UTF-8.",
     "This means that there might be problems with certain characters in file names." : "To pomeni, da se lahko pojavijo napake pri nekaterih znakih v imenih datotek.",
+    "All checks passed." : "Vsa preverjanja so uspešno zaključena.",
     "Open documentation" : "Odprta dokumentacija",
     "Allow apps to use the Share API" : "Dovoli programom uporabo vmesnika API souporabe",
     "Allow users to share via link" : "Uporabnikom dovoli omogočanje souporabe s povezavami",
@@ -134,7 +141,8 @@ OC.L10N.register(
     "Use system's cron service to call the cron.php file every 15 minutes." : "Uporabi storitev periodičnih opravil za klic datoteke cron.php vsakih 15 minut.",
     "Enable server-side encryption" : "Omogoči šifriranje na strežniku",
     "Enable encryption" : "Omogoči šifriranje",
-    "Start migration" : "Zaženite selitev",
+    "Select default encryption module:" : "Izbor privzetega modula za šifriranje:",
+    "Start migration" : "Začni selitev",
     "This is used for sending out notifications." : "Možnost je uporabljena za omogočanje pošiljanja obvestil.",
     "Send mode" : "Način pošiljanja",
     "Encryption" : "Šifriranje",
@@ -150,73 +158,71 @@ OC.L10N.register(
     "Store credentials" : "Shrani poverila",
     "Test email settings" : "Preizkus nastavitev elektronske pošte",
     "Send email" : "Pošlji elektronsko sporočilo",
-    "Log level" : "Raven beleženja",
     "Download logfile" : "Prejmi dnevniško datoteko",
     "More" : "Več",
     "Less" : "Manj",
     "The logfile is bigger than 100 MB. Downloading it may take some time!" : "Datoteeka dnevniškega zapisa je večja od 100MB. Prenos lahko traja dlje!",
+    "What to log" : "Kaj naj se beleži?",
     "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "Uporabljena baza je SQLite. Za večje namestitve priporočamo prehod na drugačno bazo.",
-    "How to do backups" : "Kako napraviti varnostne kopije",
+    "How to do backups" : "Kako ustvariti varnostne kopije",
     "Advanced monitoring" : "Napredno sledenje",
     "Performance tuning" : "Optimizacija izvajanja",
-    "Improving the config.php" : "Izboljšanje config.php",
+    "Improving the config.php" : "Izboljšave v config.php",
     "Theming" : "Teme",
-    "Hardening and security guidance" : "Varovanje in varnostni napotki",
+    "Hardening and security guidance" : "Varnost in varnostni napotki",
     "Version" : "Različica",
-    "Developer documentation" : "Razvojniška dokumentacija",
-    "Experimental applications ahead" : "Testne aplikacija",
-    "by" : "od",
-    "licensed" : "licencirano",
+    "Developer documentation" : "Dokumentacija za razvijalce",
+    "Experimental applications ahead" : "Preizkusni programi",
     "Documentation:" : "Dokumentacija:",
-    "User documentation" : "Uporabniška navodila",
-    "Show description …" : "Prikaži opis...",
-    "Hide description …" : "Skrij opis...",
+    "User documentation" : "Uporabniška dokumentacija",
+    "Admin documentation" : "Skrbniška dokumentacija",
+    "Show description …" : "Pokaži opis ...",
+    "Hide description …" : "Skrij opis ...",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "Programa ni mogoče namestiti zaradi nerešenih odvisnosti:",
     "Enable only for specific groups" : "Omogoči le za posamezne skupine",
     "Uninstall App" : "Odstrani program",
-    "Enable experimental apps" : "Omogoči testne aplikacije",
-    "No apps found for your version" : "Ni aplikacij za vašo verzijo",
+    "Enable experimental apps" : "Omogoči preizkusne programe",
+    "SSL Root Certificates" : "Korenska potrdila SSL",
+    "Common Name" : "Splošno ime",
+    "Valid until" : "Veljavno do",
+    "Issued By" : "Izdajatelj",
+    "Valid until %s" : "Veljavno do %s",
+    "Import root certificate" : "Uvozite korenski certifikat",
     "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Pozdravljeni,<br><br>samo sporočamo, da imate %s račun.<br><br>Vaše uporabniško ime: %s<br>Dostop: <a href=\"%s\">%s</a><br><br>",
     "Cheers!" : "Na zdravje!",
     "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Pozdravljeni,\n\nsamo sporočamo, da imate %s račun.\n\nVaše uporabniško ime: %s\nDostop: %s\n",
-    "Administrator documentation" : "Skrbniška navodila",
-    "Online documentation" : "Dokumentacija na spletu",
+    "Administrator documentation" : "Skrbniška dokumentacija",
+    "Online documentation" : "Spletna dokumentacija",
     "Forum" : "Forum",
     "Issue tracker" : "Spremljanje težav",
-    "Commercial support" : "Komercialna podpora",
+    "Commercial support" : "Podpora strankam",
+    "You are using <strong>%s</strong> of <strong>%s</strong>" : "Uporabljate <strong>%s</strong> od <strong>%s</strong>",
+    "Profile picture" : "Slika profila",
+    "Upload new" : "Pošlji novo",
+    "Select from Files" : "Izbor iz datotek",
+    "Remove image" : "Odstrani sliko",
+    "png or jpg, max. 20 MB" : "png ali jpg, največ. 20 MB",
+    "Cancel" : "Prekliči",
+    "Full name" : "Polno ime",
+    "No display name set" : "Ime za prikaz ni bilo nastavljeno",
+    "Email" : "Elektronski naslov",
+    "Your email address" : "Osebni elektronski naslov",
+    "No email address set" : "Poštni naslov ni bil vpisan",
+    "You are member of the following groups:" : "Vi ste član sledečih skupin:",
+    "Password" : "Geslo",
+    "Unable to change your password" : "Gesla ni mogoče spremeniti.",
+    "Current password" : "Trenutno geslo",
+    "New password" : "Novo geslo",
+    "Change password" : "Spremeni geslo",
+    "Language" : "Jezik",
+    "Help translate" : "Sodelujte pri prevajanju",
     "Get the apps to sync your files" : "Pridobi programe za usklajevanje datotek",
     "Desktop client" : "Namizni odjemalec",
     "Android app" : "Program za Android",
     "iOS app" : "Program za iOS",
     "If you want to support the project\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\tor\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "Če bi radi podprli projekt\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">pristopite razvoju</a>\n\t\tali\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">razširite glas</a>!",
     "Show First Run Wizard again" : "Zaženi čarovnika prvega zagona",
-    "You have used <strong>%s</strong> of the available <strong>%s</strong>" : "Uporabljenega je <strong>%s</strong> od razpoložljivih <strong>%s</strong> prostora.",
-    "Password" : "Geslo",
-    "Unable to change your password" : "Gesla ni mogoče spremeniti.",
-    "Current password" : "Trenutno geslo",
-    "New password" : "Novo geslo",
-    "Change password" : "Spremeni geslo",
-    "Full name" : "Polno ime",
-    "No display name set" : "Ime za prikaz ni bilo nastavljeno",
-    "Email" : "Elektronski naslov",
-    "Your email address" : "Osebni elektronski naslov",
-    "Fill in an email address to enable password recovery and receive notifications" : "Podajte elektronski naslov, da vam omogočimo reševanje izgubljenega gesla in sprejem obvestil",
-    "No email address set" : "Poštni naslov ni bil vpisan",
-    "You are member of the following groups:" : "Vi ste član sledečih skupin:",
-    "Profile picture" : "Slika profila",
-    "Upload new" : "Pošlji novo",
-    "Select new from Files" : "Izberi novo iz menija datotek",
-    "Remove image" : "Odstrani sliko",
-    "Your avatar is provided by your original account." : "Podoba je podana v izvornem računu.",
-    "Cancel" : "Prekliči",
-    "Choose as profile image" : "Izberi kot sliko profila",
-    "Language" : "Jezik",
-    "Help translate" : "Sodelujte pri prevajanju",
-    "Common Name" : "Splošno ime",
-    "Valid until" : "Veljavno do",
-    "Issued By" : "Izdajatelj",
-    "Valid until %s" : "Veljavno do %s",
-    "Import root certificate" : "Uvozite korenski certifikat",
+    "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "Produkt razvija {communityopen}ownCloud skupnost{linkclose},  {githubopen}izvorna koda{linkclose} je licencirana pod {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}.",
     "Show storage location" : "Pokaži mesto shrambe",
     "Show last log in" : "Pokaži podatke zadnje prijave",
     "Show user backend" : "Pokaži ozadnji program",
