@@ -11,12 +11,10 @@ OC.L10N.register(
     "Log" : "Журнал",
     "Tips & tricks" : "Поради і трюки",
     "Updates" : "Оновлення",
-    "Authentication error" : "Помилка автентифікації",
-    "Your full name has been changed." : "Ваше повне ім'я було змінено",
-    "Unable to change full name" : "Неможливо змінити повне ім'я",
     "Couldn't remove app." : "Неможливо видалити додаток.",
     "Language changed" : "Мову змінено",
     "Invalid request" : "Некоректний запит",
+    "Authentication error" : "Помилка автентифікації",
     "Admins can't remove themself from the admin group" : "Адміністратор не може видалити себе з групи адміністраторів",
     "Unable to add user to group %s" : "Не вдалося додати користувача у групу %s",
     "Unable to remove user from group %s" : "Не вдалося видалити користувача із групи %s",
@@ -52,6 +50,8 @@ OC.L10N.register(
     "Invalid user" : "Неправильний користувач",
     "Unable to change mail address" : "Неможливо поміняти email адресу",
     "Email saved" : "Адресу збережено",
+    "Your full name has been changed." : "Ваше повне ім'я було змінено",
+    "Unable to change full name" : "Неможливо змінити повне ім'я",
     "Are you really sure you want add \"{domain}\" as trusted domain?" : "Ви дійсно бажаєте додати \"{domain}\" як довірений домен?",
     "Add trusted domain" : "Додати довірений домен",
     "Migration in progress. Please wait until the migration is finished" : "Міграція триває. Будь ласка, зачекайте доки процес міграції завершиться",
@@ -61,6 +61,7 @@ OC.L10N.register(
     "Approved" : "Схвалені",
     "Experimental" : "Експериментальні",
     "All" : "Всі",
+    "No apps found for your version" : "Немає застосунків для вашої версії",
     "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "Офіційні додатки розроблені спільнотою ownCloud. Вони реалізують основні можливості ownCloud і готові до використання в продакшені.",
     "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Схвалені додатки розроблені довіреними розробниками і пройшли незалежну перевірку безпеки. Їх активно супроводжують у репозиторії з відкритим кодом, а їх розробники стежать, щоб вони були стабільні й прийнятні для повсякденного використання.",
     "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Ця програма не перевірена на вразливості безпеки і є новою або нестабільною. Встановлюйте її на власний ризик.",
@@ -76,6 +77,11 @@ OC.L10N.register(
     "Uninstalling ...." : "Видалення...",
     "Error while uninstalling app" : "Помилка видалення додатка",
     "Uninstall" : "Видалити",
+    "App update" : "Оновлення додатку",
+    "No apps found for \"{query}\"" : "Не знайдено додатків для \"{query}\"",
+    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Виникла помилка. Будь ласка вивантажте PEM сертифікат в ASCII-кодуванні.",
+    "Valid until {date}" : "Дійсно до {date}",
+    "Delete" : "Видалити",
     "An error occurred: {message}" : "Сталася помилка: {message}",
     "Select a profile picture" : "Обрати зображення облікового запису",
     "Very weak password" : "Дуже слабкий пароль",
@@ -83,12 +89,8 @@ OC.L10N.register(
     "So-so password" : "Такий собі пароль",
     "Good password" : "Добрий пароль",
     "Strong password" : "Надійний пароль",
-    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Виникла помилка. Будь ласка вивантажте PEM сертифікат в ASCII-кодуванні.",
-    "Valid until {date}" : "Дійсно до {date}",
-    "Delete" : "Видалити",
     "Groups" : "Групи",
     "Unable to delete {objName}" : "Не вдалося видалити {objName}",
-    "Error creating group" : "Помилка створення групи",
     "A valid group name must be provided" : "Потрібно задати вірне ім'я групи",
     "deleted {groupName}" : "видалено {groupName}",
     "undo" : "відмінити",
@@ -98,13 +100,11 @@ OC.L10N.register(
     "add group" : "додати групу",
     "Changing the password will result in data loss, because data recovery is not available for this user" : "Зміна пароля призведе до втрати даних, тому що відновлення даних не доступно для цього користувача",
     "A valid username must be provided" : "Потрібно задати вірне ім'я користувача",
-    "Error creating user" : "Помилка при створенні користувача",
     "A valid password must be provided" : "Потрібно задати вірний пароль",
     "A valid email must be provided" : "Вкажіть дійсний email",
     "__language_name__" : "__language_name__",
-    "Sync clients" : "Клієнти синхронізації",
     "Personal info" : "Особиста інформація",
-    "SSL root certificates" : "Кореневі SSL сертифікати",
+    "Sync clients" : "Клієнти синхронізації",
     "Everything (fatal issues, errors, warnings, info, debug)" : "Усі (критичні проблеми, помилки, попередження, інформаційні, налагодження)",
     "Info, warnings, errors and fatal issues" : "Інформаційні, попередження, помилки та критичні проблеми",
     "Warnings, errors and fatal issues" : "Попередження, помилки та критичні проблеми",
@@ -150,6 +150,7 @@ OC.L10N.register(
     "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php зареєстрований в службі webcron та буде викликатися кожні 15 хвилин через HTTP.",
     "Use system's cron service to call the cron.php file every 15 minutes." : "Використовувати системний cron для виклику cron.php кожні 15 хвилин.",
     "Enable server-side encryption" : "Увімкнути шифрування на сервері",
+    "Please read carefully before activating server-side encryption: " : "Будьте обережні під час активування шифрування на сервері:",
     "Enable encryption" : "Увімкнути шифрування",
     "Select default encryption module:" : "Обрати модуль шифрування за замовчуванням:",
     "Start migration" : "Розпочати міграцію",
@@ -168,7 +169,6 @@ OC.L10N.register(
     "Store credentials" : "Зберігати облікові дані",
     "Test email settings" : "Тестувати налаштування електронної пошти",
     "Send email" : "Надіслати листа",
-    "Log level" : "Рівень протоколювання",
     "Download logfile" : "Завантажити файл журналу",
     "More" : "Більше",
     "Less" : "Менше",
@@ -185,8 +185,6 @@ OC.L10N.register(
     "Developer documentation" : "Документація для розробників",
     "Experimental applications ahead" : "Спершу експериментальні додатки",
     "Experimental apps are not checked for security issues, new or known to be unstable and under heavy development. Installing them can cause data loss or security breaches." : "Експериментальні додатки не перевірені на наявність проблем безпеки, нові або нестабільні і в процесі активної розробки. Встановлення їх може спричинити втрату даних або дірки в безпеці.",
-    "by" : "по",
-    "licensed" : "Ліцензовано",
     "Documentation:" : "Документація:",
     "User documentation" : "Користувацька документація",
     "Admin documentation" : "Документація адміністратора",
@@ -196,7 +194,11 @@ OC.L10N.register(
     "Enable only for specific groups" : "Включити тільки для конкретних груп",
     "Uninstall App" : "Видалити додаток",
     "Enable experimental apps" : "Увімкнути експериментальні застосунки",
-    "No apps found for your version" : "Немає застосунків для вашої версії",
+    "Common Name" : "Ім'я:",
+    "Valid until" : "Дійсно до",
+    "Issued By" : "Виданий",
+    "Valid until %s" : "Дійсно до %s",
+    "Import root certificate" : "Імпортувати кореневий сертифікат",
     "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Агов,<br><br>просто щоб ви знали, у вас є аккаунт %s.<br><br>Ваше ім'я користувача: %s<br>Перейдіть сюди: <a href=\"%s\">%s</a><br><br>",
     "Cheers!" : "Будьмо!",
     "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Агов,\n\nпросто щоб ви знали, у вас є аккаунт %s.\n\nВаше ім'я користувача: %s\nПерейдіть сюди: %s\n\n",
@@ -205,39 +207,31 @@ OC.L10N.register(
     "Forum" : "Форум",
     "Issue tracker" : "Вирішення проблем",
     "Commercial support" : "Комерційна підтримка",
+    "You are using <strong>%s</strong> of <strong>%s</strong>" : "Ви використовуєте <strong>%s</strong> з <strong>%s</strong>",
+    "Profile picture" : "Зображення облікового запису",
+    "Upload new" : "Завантажити нове",
+    "Remove image" : "Видалити зображення",
+    "Cancel" : "Відмінити",
+    "Choose as profile picture" : "Обрати як зображення для профілю",
+    "Full name" : "Повне ім'я",
+    "No display name set" : "Коротке ім'я не вказано",
+    "Email" : "E-mail",
+    "Your email address" : "Ваша адреса електронної пошти",
+    "No email address set" : "E-mail не вказано",
+    "You are member of the following groups:" : "Ви є членом наступних груп:",
+    "Password" : "Пароль",
+    "Unable to change your password" : "Не вдалося змінити Ваш пароль",
+    "Current password" : "Поточний пароль",
+    "New password" : "Новий пароль",
+    "Change password" : "Змінити пароль",
+    "Language" : "Мова",
+    "Help translate" : "Допомогти з перекладом",
     "Get the apps to sync your files" : "Отримати додатки для синхронізації ваших файлів",
     "Desktop client" : "Клієнт для ПК",
     "Android app" : "Android-додаток",
     "iOS app" : "iOS додаток",
     "If you want to support the project\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\tor\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "Якщо Ви хочете підтримати проект\n⇥⇥ <a href=\"https://owncloud.org/contribute\"\n⇥⇥⇥target=\"_blank\" rel=\"noreferrer\"> спільна розробка </a> \n⇥⇥або\n⇥ ⇥ <a href=\"https://owncloud.org/promote\"\n ⇥⇥⇥target=\"_blank\" rel=\"noreferrer\"> повідомити у світі </a> !",
     "Show First Run Wizard again" : "Показувати Майстер Налаштувань знову",
-    "You have used <strong>%s</strong> of the available <strong>%s</strong>" : "Ви використали <strong>%s</strong> із доступних <strong>%s</strong>",
-    "Password" : "Пароль",
-    "Unable to change your password" : "Не вдалося змінити Ваш пароль",
-    "Current password" : "Поточний пароль",
-    "New password" : "Новий пароль",
-    "Change password" : "Змінити пароль",
-    "Full name" : "Повне ім'я",
-    "No display name set" : "Коротке ім'я не вказано",
-    "Email" : "E-mail",
-    "Your email address" : "Ваша адреса електронної пошти",
-    "Fill in an email address to enable password recovery and receive notifications" : "Введіть адресу електронної пошти, щоб ввімкнути відновлення паролю та отримання повідомлень",
-    "No email address set" : "E-mail не вказано",
-    "You are member of the following groups:" : "Ви є членом наступних груп:",
-    "Profile picture" : "Зображення облікового запису",
-    "Upload new" : "Завантажити нове",
-    "Select new from Files" : "Обрати із завантажених файлів",
-    "Remove image" : "Видалити зображення",
-    "Your avatar is provided by your original account." : "Буде використано аватар вашого оригінального облікового запису.",
-    "Cancel" : "Відмінити",
-    "Choose as profile image" : "Обрати зображенням облікового запису",
-    "Language" : "Мова",
-    "Help translate" : "Допомогти з перекладом",
-    "Common Name" : "Ім'я:",
-    "Valid until" : "Дійсно до",
-    "Issued By" : "Виданий",
-    "Valid until %s" : "Дійсно до %s",
-    "Import root certificate" : "Імпортувати кореневий сертифікат",
     "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "Розроблено {communityopen} спільнотою ownCloud {linkclose}, {githubopen} вихідний код {linkclose} ліцензується відповідно до {licenseopen} <abbr title = \"Публічної ліцензії Affero General\"> AGPL </ abbr> {linkclose}.",
     "Show storage location" : "Показати місцезнаходження сховища",
     "Show last log in" : "Показати останній вхід в систему",
